@@ -349,21 +349,36 @@ void write_source_line (FILE_T f, LINE_T * p, NODE_T * nwhere, int mask)
   }
 }
 
-//! @brief Write diagnostics to STDOUT.
+//! @brief Write diagnostics to STDERR.
 
 void diagnostics_to_terminal (LINE_T * p, int sev)
 {
   for (; p != NO_LINE; FORWARD (p)) {
     if (DIAGNOSTICS (p) != NO_DIAGNOSTIC) {
-      BOOL_T z = A68G_FALSE;
+      int N = 0;
       for (DIAGNOSTIC_T *d = DIAGNOSTICS (p); d != NO_DIAGNOSTIC; FORWARD (d)) {
         if (sev == A68G_ALL_DIAGNOSTICS) {
-          z = (BOOL_T) (z | (IS (d, A68G_WARNING) || IS (d, A68G_ERROR) || IS (d, A68G_SYNTAX_ERROR) || IS (d, A68G_MATH_ERROR) || IS (d, A68G_RUNTIME_ERROR) || IS (d, A68G_SCANNER_ERROR)));
-        } else if (sev == A68G_RUNTIME_ERROR) {
-          z = (BOOL_T) (z | (IS (d, A68G_RUNTIME_ERROR) || (IS (d, A68G_MATH_ERROR))));
+          if (
+            IS (d, A68G_ERROR)         || 
+            IS (d, A68G_NOTICE)        || 
+            IS (d, A68G_SCANNER_ERROR) ||
+            IS (d, A68G_SYNTAX_ERROR)  || 
+            IS (d, A68G_WARNING)
+          ) {
+            N++;
+          }
+        } 
+        if (sev == A68G_ALL_DIAGNOSTICS || sev == A68G_RUNTIME_ERROR) {
+          if (
+            IS (d, A68G_MATH_ERROR)   ||
+            IS (d, A68G_MATH_WARNING) ||
+            IS (d, A68G_RUNTIME_ERROR)
+          ) {
+            N++;
+          }
         }
       }
-      if (z) {
+      if (N > 0) {
         write_source_line (A68G_STDERR, p, NO_NODE, sev);
       }
     }
@@ -432,6 +447,9 @@ char *get_severity (int sev)
   case A68G_MATH_WARNING: {
       return "math warning";
     }
+  case A68G_NOTICE: {
+      return "notice";
+    }
   case A68G_WARNING: {
       return "warning";
     }
@@ -573,7 +591,11 @@ void diagnostic (STATUS_MASK_T sev, NODE_T * p, char *loc_str, ...)
     line = va_arg (args, LINE_T *);
     pos = va_arg (args, char *);
   }
-// No warnings?
+// No warnings or notices?
+  if (!force && sev == A68G_NOTICE && OPTION_NO_NOTICES (&A68G_JOB)) {
+    va_end (args);
+    return;
+  }
   if (!force && sev == A68G_WARNING && OPTION_NO_WARNINGS (&A68G_JOB)) {
     va_end (args);
     return;
@@ -582,6 +604,10 @@ void diagnostic (STATUS_MASK_T sev, NODE_T * p, char *loc_str, ...)
     va_end (args);
     return;
   }
+  if (sev == A68G_NOTICE && OPTION_QUIET (&A68G_JOB)) {
+    va_end (args);
+    return;
+  }
   if (sev == A68G_WARNING && OPTION_QUIET (&A68G_JOB)) {
     va_end (args);
     return;
@@ -600,7 +626,7 @@ void diagnostic (STATUS_MASK_T sev, NODE_T * p, char *loc_str, ...)
       ERROR_COUNT (&A68G_JOB)++;
       compose = issue = A68G_FALSE;
     }
-  } else if (sev == A68G_WARNING || sev == A68G_MATH_WARNING) {
+  } else if (sev == A68G_NOTICE || sev == A68G_WARNING || sev == A68G_MATH_WARNING) {
     if (WARNING_COUNT (&A68G_JOB) == MAX_ERRORS) {
       a68g_bufcpy (b, "further diagnostics suppressed", BUFFER_SIZE);
       compose = A68G_FALSE;
@@ -817,7 +843,7 @@ void diagnostic (STATUS_MASK_T sev, NODE_T * p, char *loc_str, ...)
   }
 // Construct a diagnostic message.
   if (issue) {
-    if (sev == A68G_WARNING) {
+    if (sev == A68G_NOTICE || sev == A68G_WARNING) {
       WARNING_COUNT (&A68G_JOB)++;
     } else {
       ERROR_COUNT (&A68G_JOB)++;
