@@ -30,23 +30,23 @@
 
 void init_tty (void)
 {
-  A68 (chars_in_stderr) = 0;
-  A68 (chars_in_stdout) = 0;
-  A68 (halt_typing) = A68_FALSE;
-  change_masks (TOP_NODE (&A68_JOB), BREAKPOINT_INTERRUPT_MASK, A68_FALSE);
+  A68G (chars_in_stderr) = 0;
+  A68G (chars_in_stdout) = 0;
+  A68G (halt_typing) = A68G_FALSE;
+  change_masks (TOP_NODE (&A68G_JOB), BREAKPOINT_INTERRUPT_MASK, A68G_FALSE);
 }
 
 //! @brief Terminate current line on STDOUT.
 
 void io_close_tty_line (void)
 {
-  if (A68 (chars_in_stderr) > 0) {
-    A68 (chars_in_stderr) = 0;
-    io_write_string (A68_STDERR, NEWLINE_STRING);
+  if (A68G (chars_in_stderr) > 0) {
+    A68G (chars_in_stderr) = 0;
+    io_write_string (A68G_STDERR, NEWLINE_STRING);
   }
-  if (A68 (chars_in_stdout) > 0) {
-    A68 (chars_in_stdout) = 0;
-    io_write_string (A68_STDOUT, NEWLINE_STRING);
+  if (A68G (chars_in_stdout) > 0) {
+    A68G (chars_in_stdout) = 0;
+    io_write_string (A68G_STDOUT, NEWLINE_STRING);
   }
 }
 
@@ -56,7 +56,7 @@ char get_stdin_char (void)
 {
   char ch[4];
   errno = 0;
-  ssize_t j = io_read_conv (A68_STDIN, &(ch[0]), 1);
+  ssize_t j = io_read_conv (A68G_STDIN, &(ch[0]), 1);
   ABEND (j < 0, ERROR_ACTION, __func__);
   return (char) (j == 1 ? ch[0] : EOF_CHAR);
 }
@@ -70,32 +70,32 @@ char *read_string_from_tty (char *prompt)
   if (line != NO_TEXT && (int) strlen (line) > 0) {
     add_history (line);
   }
-  a68g_bufcpy (A68 (input_line), line, BUFFER_SIZE);
-  A68 (chars_in_stdout) = (int) strlen (A68 (input_line));
+  a68g_bufcpy (A68G (input_line), line, BUFFER_SIZE);
+  A68G (chars_in_stdout) = (int) strlen (A68G (input_line));
   a68g_free (line);
-  return A68 (input_line);
+  return A68G (input_line);
 #else
   int ch, k = 0, n;
   if (prompt != NO_TEXT) {
     io_close_tty_line ();
-    io_write_string (A68_STDOUT, prompt);
+    io_write_string (A68G_STDOUT, prompt);
   }
   ch = get_stdin_char ();
   while (ch != NEWLINE_CHAR && k < BUFFER_SIZE - 1) {
     if (ch == EOF_CHAR) {
-      A68 (input_line)[0] = EOF_CHAR;
-      A68 (input_line)[1] = NULL_CHAR;
-      A68 (chars_in_stdout) = 1;
-      return A68 (input_line);
+      A68G (input_line)[0] = EOF_CHAR;
+      A68G (input_line)[1] = NULL_CHAR;
+      A68G (chars_in_stdout) = 1;
+      return A68G (input_line);
     } else {
-      A68 (input_line)[k++] = (char) ch;
+      A68G (input_line)[k++] = (char) ch;
       ch = get_stdin_char ();
     }
   }
-  A68 (input_line)[k] = NULL_CHAR;
-  n = (int) strlen (A68 (input_line));
-  A68 (chars_in_stdout) = (ch == NEWLINE_CHAR ? 0 : (n > 0 ? n : 1));
-  return A68 (input_line);
+  A68G (input_line)[k] = NULL_CHAR;
+  n = (int) strlen (A68G (input_line));
+  A68G (chars_in_stdout) = (ch == NEWLINE_CHAR ? 0 : (n > 0 ? n : 1));
+  return A68G (input_line);
 #endif
 }
 
@@ -104,7 +104,7 @@ char *read_string_from_tty (char *prompt)
 void io_write_string (FILE_T f, const char *z)
 {
   errno = 0;
-  if (f != A68_STDOUT && f != A68_STDERR) {
+  if (f != A68G_STDOUT && f != A68G_STDERR) {
 // Writing to file.
     ssize_t j = io_write_conv (f, z, strlen (z));
     ABEND (j < 0, ERROR_ACTION, __func__);
@@ -122,10 +122,10 @@ void io_write_string (FILE_T f, const char *z)
         int n = k - first;
         ssize_t j = io_write_conv (f, &(z[first]), (size_t) n);
         ABEND (j < 0, ERROR_ACTION, __func__);
-        if (f == A68_STDERR) {
-          A68 (chars_in_stderr) += n;
+        if (f == A68G_STDERR) {
+          A68G (chars_in_stderr) += n;
         } else {
-          A68 (chars_in_stdout) += n;
+          A68G (chars_in_stdout) += n;
         }
       }
       if (z[k] == NEWLINE_CHAR) {
@@ -134,10 +134,10 @@ void io_write_string (FILE_T f, const char *z)
         first = k;
         ssize_t j = io_write_conv (f, NEWLINE_STRING, 1);
         ABEND (j < 0, ERROR_ACTION, __func__);
-        if (f == A68_STDERR) {
-          A68 (chars_in_stderr) = 0;
+        if (f == A68G_STDERR) {
+          A68G (chars_in_stderr) = 0;
         } else {
-          A68 (chars_in_stdout) = 0;
+          A68G (chars_in_stdout) = 0;
         }
       }
     } while (z[k] != NULL_CHAR);
