@@ -165,6 +165,7 @@ void default_options (MODULE_T * p)
   OPTION_LICENSE (p) = A68G_FALSE;
   OPTION_MOID_LISTING (p) = A68G_FALSE;
   OPTION_NODEMASK (p) = (STATUS_MASK_T) (ASSERT_MASK | SOURCE_MASK);
+  OPTION_NO_NOTICES (p) = A68G_TRUE;
   OPTION_NO_WARNINGS (p) = A68G_FALSE;
   OPTION_OPT_LEVEL (p) = NO_OPTIMISE;
   OPTION_PORTCHECK (p) = A68G_FALSE;
@@ -803,6 +804,7 @@ BOOL_T set_options (OPTION_LIST_T *i, BOOL_T cmd_line)
           }
           skip = A68G_TRUE;
           OPTION_RUN_SCRIPT (&A68G_JOB) = A68G_TRUE;
+          OPTION_NO_NOTICES (&A68G_JOB) = A68G_TRUE;
           OPTION_NO_WARNINGS (&A68G_JOB) = A68G_TRUE;
           OPTION_COMPILE (&A68G_JOB) = A68G_FALSE;
 #else
@@ -905,7 +907,8 @@ BOOL_T set_options (OPTION_LIST_T *i, BOOL_T cmd_line)
           OPTION_DEBUG (&A68G_JOB) = A68G_TRUE;
         }
 // REGRESSION is an option that sets preferences when running the test suite - undocumented option.
-        else if (eq (p, "REGRESSION")) {
+        else if (eq (p, "REGRession")) {
+          OPTION_NO_NOTICES (&A68G_JOB) = A68G_FALSE;
           OPTION_NO_WARNINGS (&A68G_JOB) = A68G_FALSE;
           OPTION_PORTCHECK (&A68G_JOB) = A68G_TRUE;
           OPTION_REGRESSION_TEST (&A68G_JOB) = A68G_TRUE;
@@ -917,13 +920,19 @@ BOOL_T set_options (OPTION_LIST_T *i, BOOL_T cmd_line)
         else if (eq (p, "LICense")) {
           OPTION_LICENSE (&A68G_JOB) = A68G_TRUE;
         }
+// NONOTICES switches notices off.
+        else if (eq (p, "NONotices")) {
+          OPTION_NO_NOTICES (&A68G_JOB) = A68G_TRUE;
+        } else if (eq (p, "NO-NOTICEs")) {
+          OPTION_NO_NOTICES (&A68G_JOB) = A68G_TRUE;
+        }
 // NOWARNINGS switches unsuppressible warnings off.
         else if (eq (p, "NOWarnings")) {
           OPTION_NO_WARNINGS (&A68G_JOB) = A68G_TRUE;
         } else if (eq (p, "NO-Warnings")) {
           OPTION_NO_WARNINGS (&A68G_JOB) = A68G_TRUE;
         }
-// QUIET switches all warnings off.
+// QUIET switches all warnings and notices off.
         else if (eq (p, "Quiet")) {
           OPTION_QUIET (&A68G_JOB) = A68G_TRUE;
         }
@@ -931,6 +940,10 @@ BOOL_T set_options (OPTION_LIST_T *i, BOOL_T cmd_line)
         else if (eq (p, "Warnings")) {
           OPTION_NO_WARNINGS (&A68G_JOB) = A68G_FALSE;
         }
+// NOTICES switches notices on.
+        else if (eq (p, "NOTices")) {
+          OPTION_NO_NOTICES (&A68G_JOB) = A68G_FALSE;
+        }
 // NOPORTCHECK switches portcheck off.
         else if (eq (p, "NOPORTcheck")) {
           OPTION_PORTCHECK (&A68G_JOB) = A68G_FALSE;
@@ -944,6 +957,7 @@ BOOL_T set_options (OPTION_LIST_T *i, BOOL_T cmd_line)
 // PEDANTIC switches portcheck and warnings on.
         else if (eq (p, "PEDANTIC")) {
           OPTION_PORTCHECK (&A68G_JOB) = A68G_TRUE;
+          OPTION_NO_NOTICES (&A68G_JOB) = A68G_FALSE;
           OPTION_NO_WARNINGS (&A68G_JOB) = A68G_FALSE;
         }
 // PRAGMATS and NOPRAGMATS switch on/off pragmat processing.
