@@ -163,7 +163,7 @@ char *a68g_relpath (char *p1, char *p2, char *fn)
 
 void genie_realpath (NODE_T * p)
 {
-  A68_REF str;
+  A68G_REF str;
   POP_REF (p, &str);
   char in[PATH_MAX + 1];
   if (a_to_c_string (p, in, str) == NO_TEXT) {
