@@ -100,9 +100,9 @@ void pad_node (NODE_T * p, int a)
 void a68g_extension (NODE_T * p)
 {
   if (OPTION_PORTCHECK (&A68G_JOB)) {
-    diagnostic (A68G_WARNING | A68G_FORCE_DIAGNOSTICS, p, WARNING_EXTENSION);
-  } else {
     diagnostic (A68G_WARNING, p, WARNING_EXTENSION);
+  } else {
+    diagnostic (A68G_NOTICE, p, WARNING_EXTENSION);
   }
 }
 
