@@ -68,7 +68,7 @@
 
 char *optimisation_option (void)
 {
-  switch (OPTION_OPT_LEVEL (&A68_JOB)) {
+  switch (OPTION_OPT_LEVEL (&A68G_JOB)) {
   case OPTIMISE_0: {
       return "-Og";
     }
@@ -94,25 +94,25 @@ char *optimisation_option (void)
 
 void plugin_driver_emit (FILE_T out)
 {
-  ADDR_T pop_temp_heap_pointer = A68 (temp_heap_pointer);
-  if (OPTION_OPT_LEVEL (&A68_JOB) == NO_OPTIMISE) {
+  ADDR_T pop_temp_heap_pointer = A68G (temp_heap_pointer);
+  if (OPTION_OPT_LEVEL (&A68G_JOB) == NO_OPTIMISE) {
     return;
   }
-  A68_OPT (indentation) = 0;
-  A68_OPT (code_errors) = 0;
-  A68_OPT (procedures) = 0;
-  A68_OPT (cse_pointer) = 0;
-  A68_OPT (unic_pointer) = 0;
-  A68_OPT (root_idf) = NO_DEC;
-  A68 (global_level) = INT_MAX;
-  A68_GLOBALS = 0;
-  get_global_level (SUB (TOP_NODE (&A68_JOB)));
-  A68 (max_lex_lvl) = 0;
-  genie_preprocess (TOP_NODE (&A68_JOB), &A68 (max_lex_lvl), NULL);
-  get_global_level (TOP_NODE (&A68_JOB));
-  A68_SP = A68 (stack_start);
-  A68 (expr_stack_limit) = A68 (stack_end) - A68 (storage_overhead);
-  if (OPTION_COMPILE_CHECK (&A68_JOB)) {
+  A68G_OPT (indentation) = 0;
+  A68G_OPT (code_errors) = 0;
+  A68G_OPT (procedures) = 0;
+  A68G_OPT (cse_pointer) = 0;
+  A68G_OPT (unic_pointer) = 0;
+  A68G_OPT (root_idf) = NO_DEC;
+  A68G (global_level) = INT_MAX;
+  A68G_GLOBALS = 0;
+  get_global_level (SUB (TOP_NODE (&A68G_JOB)));
+  A68G (max_lex_lvl) = 0;
+  genie_preprocess (TOP_NODE (&A68G_JOB), &A68G (max_lex_lvl), NULL);
+  get_global_level (TOP_NODE (&A68G_JOB));
+  A68G_SP = A68G (stack_start);
+  A68G (expr_stack_limit) = A68G (stack_end) - A68G (storage_overhead);
+  if (OPTION_COMPILE_CHECK (&A68G_JOB)) {
     monadics = monadics_check;
     dyadics = dyadics_check;
     functions = functions_check;
@@ -121,26 +121,26 @@ void plugin_driver_emit (FILE_T out)
     dyadics = dyadics_nocheck;
     functions = functions_nocheck;
   }
-  if (OPTION_OPT_LEVEL (&A68_JOB) == OPTIMISE_0) {
+  if (OPTION_OPT_LEVEL (&A68G_JOB) == OPTIMISE_0) {
 // Allow basic optimisation only.
-    A68_OPT (OPTION_CODE_LEVEL) = 1;
+    A68G_OPT (OPTION_CODE_LEVEL) = 1;
     write_prelude (out);
-    gen_basics (TOP_NODE (&A68_JOB), out);
+    gen_basics (TOP_NODE (&A68G_JOB), out);
   } else {
 // Allow all optimisations.
-    A68_OPT (OPTION_CODE_LEVEL) = 9;
+    A68G_OPT (OPTION_CODE_LEVEL) = 9;
     write_prelude (out);
-    gen_units (TOP_NODE (&A68_JOB), out);
+    gen_units (TOP_NODE (&A68G_JOB), out);
   }
-  ABEND (A68_OPT (indentation) != 0, ERROR_INTERNAL_CONSISTENCY, __func__);
+  ABEND (A68G_OPT (indentation) != 0, ERROR_INTERNAL_CONSISTENCY, __func__);
 // At the end we discard temporary declarations.
-  A68 (temp_heap_pointer) = pop_temp_heap_pointer;
-  if (OPTION_VERBOSE (&A68_JOB)) {
-    ASSERT (a68g_bufprt (A68 (output_line), SNPRINTF_SIZE, "%s: A68_OPT (procedures)=%d unique-names=%d", A68 (a68g_cmd_name), A68_OPT (procedures), A68_OPT (unic_pointer)) >= 0);
+  A68G (temp_heap_pointer) = pop_temp_heap_pointer;
+  if (OPTION_VERBOSE (&A68G_JOB)) {
+    ASSERT (a68g_bufprt (A68G (output_line), SNPRINTF_SIZE, "%s: procedures=%d unique-names=%d", A68G (a68g_cmd_name), A68G_OPT (procedures), A68G_OPT (unic_pointer)) >= 0);
     io_close_tty_line ();
-    WRITE (A68_STDOUT, A68 (output_line));
+    WRITE (A68G_STDOUT, A68G (output_line));
   }
-  for (int k = 0; k < A68_OPT (unic_pointer); k++) {
+  for (int k = 0; k < A68G_OPT (unic_pointer); k++) {
     a68g_free (UNIC_NAME (k));
   }
 }
@@ -182,7 +182,7 @@ char *moid_with_name (char *pre, MOID_T * m, char *post)
 
 void indent (FILE_T out, char *str)
 {
-  int j = A68_OPT (indentation);
+  int j = A68G_OPT (indentation);
   if (out == 0) {
     return;
   }
@@ -210,9 +210,9 @@ void indentf (FILE_T out, int ret)
     return;
   }
   if (ret >= 0) {
-    indent (out, A68 (edit_line));
+    indent (out, A68G (edit_line));
   } else {
-    ABEND (A68_TRUE, ERROR_INTERNAL_CONSISTENCY, error_specification ());
+    ABEND (A68G_TRUE, ERROR_INTERNAL_CONSISTENCY, error_specification ());
   }
 }
 
@@ -224,9 +224,9 @@ void undentf (FILE_T out, int ret)
     return;
   }
   if (ret >= 0) {
-    WRITE (out, A68 (edit_line));
+    WRITE (out, A68G (edit_line));
   } else {
-    ABEND (A68_TRUE, ERROR_INTERNAL_CONSISTENCY, error_specification ());
+    ABEND (A68G_TRUE, ERROR_INTERNAL_CONSISTENCY, error_specification ());
   }
 }
 
@@ -245,7 +245,7 @@ DEC_T *add_identifier (DEC_T ** p, int level, char *idf)
     } else if (k > 0) {
       p = &MORE (*p);
     } else {
-      ABEND (A68_TRUE, ERROR_INTERNAL_CONSISTENCY, z);
+      ABEND (A68G_TRUE, ERROR_INTERNAL_CONSISTENCY, z);
       return *p;
     }
   }
@@ -286,10 +286,10 @@ void print_identifiers (FILE_T out, DEC_T * p)
 {
   if (p != NO_DEC) {
     print_identifiers (out, LESS (p));
-    if (A68_OPT (put_idf_comma)) {
+    if (A68G_OPT (put_idf_comma)) {
       WRITE (out, ", ");
     } else {
-      A68_OPT (put_idf_comma) = A68_TRUE;
+      A68G_OPT (put_idf_comma) = A68G_TRUE;
     }
     if (LEVEL (p) > 0) {
       int k = LEVEL (p);
@@ -311,7 +311,7 @@ void print_declarations (FILE_T out, DEC_T * p)
     print_declarations (out, LESS (p));
     indent (out, TEXT (p));
     WRITE (out, " ");
-    A68_OPT (put_idf_comma) = A68_FALSE;
+    A68G_OPT (put_idf_comma) = A68G_FALSE;
     print_identifiers (out, SUB (p));
     WRITE (out, ";\n");
     print_declarations (out, MORE (p));
@@ -338,7 +338,7 @@ char *make_unic_name (char *buf, char *name, char *tag, char *ext)
 
 char *signed_in_name (char *name)
 {
-  for (int k = 0; k < A68_OPT (unic_pointer); k++) {
+  for (int k = 0; k < A68G_OPT (unic_pointer); k++) {
     if (strcmp (UNIC_NAME (k), name) == 0) {
       return UNIC_NAME (k);
     }
@@ -352,9 +352,9 @@ void sign_in_name (char *name, int *action)
 {
   if (signed_in_name (name)) {
     *action = UNIC_EXISTS;
-  } else if (A68_OPT (unic_pointer) < MAX_UNIC) {
-    UNIC_NAME (A68_OPT (unic_pointer)) = new_string (name, NO_TEXT);
-    A68_OPT (unic_pointer)++;
+  } else if (A68G_OPT (unic_pointer) < MAX_UNIC) {
+    UNIC_NAME (A68G_OPT (unic_pointer)) = new_string (name, NO_TEXT);
+    A68G_OPT (unic_pointer)++;
     *action = UNIC_MAKE_NEW;
   } else {
     *action = UNIC_MAKE_ALT;
@@ -365,13 +365,13 @@ void sign_in_name (char *name, int *action)
 
 void sign_in (int action, int phase, char *idf, void *info, int number)
 {
-  if (A68_OPT (cse_pointer) < MAX_BOOK) {
-    ACTION (&A68_OPT (cse_book)[A68_OPT (cse_pointer)]) = action;
-    PHASE (&A68_OPT (cse_book)[A68_OPT (cse_pointer)]) = phase;
-    IDF (&A68_OPT (cse_book)[A68_OPT (cse_pointer)]) = idf;
-    INFO (&A68_OPT (cse_book)[A68_OPT (cse_pointer)]) = info;
-    NUMBER (&A68_OPT (cse_book)[A68_OPT (cse_pointer)]) = number;
-    A68_OPT (cse_pointer)++;
+  if (A68G_OPT (cse_pointer) < MAX_BOOK) {
+    ACTION (&A68G_OPT (cse_book)[A68G_OPT (cse_pointer)]) = action;
+    PHASE (&A68G_OPT (cse_book)[A68G_OPT (cse_pointer)]) = phase;
+    IDF (&A68G_OPT (cse_book)[A68G_OPT (cse_pointer)]) = idf;
+    INFO (&A68G_OPT (cse_book)[A68G_OPT (cse_pointer)]) = info;
+    NUMBER (&A68G_OPT (cse_book)[A68G_OPT (cse_pointer)]) = number;
+    A68G_OPT (cse_pointer)++;
   }
 }
 
@@ -379,9 +379,9 @@ void sign_in (int action, int phase, char *idf, void *info, int number)
 
 BOOK_T *signed_in (int action, int phase, const char *idf)
 {
-  for (int k = 0; k < A68_OPT (cse_pointer); k++) {
-    if (IDF (&A68_OPT (cse_book)[k]) == idf && ACTION (&A68_OPT (cse_book)[k]) == action && PHASE (&A68_OPT (cse_book)[k]) >= phase) {
-      return &(A68_OPT (cse_book)[k]);
+  for (int k = 0; k < A68G_OPT (cse_pointer); k++) {
+    if (IDF (&A68G_OPT (cse_book)[k]) == idf && ACTION (&A68G_OPT (cse_book)[k]) == action && PHASE (&A68G_OPT (cse_book)[k]) >= phase) {
+      return &(A68G_OPT (cse_book)[k]);
     }
   }
   return NO_BOOK;
@@ -411,7 +411,7 @@ BOOL_T same_tree (NODE_T * l, NODE_T * r)
   } else if (ATTRIBUTE (l) == ATTRIBUTE (r) && NSYMBOL (l) == NSYMBOL (r)) {
     return (BOOL_T) (same_tree (SUB (l), SUB (r)) && same_tree (NEXT (l), NEXT (r)));
   } else {
-    return A68_FALSE;
+    return A68G_FALSE;
   }
 }
 
@@ -446,17 +446,17 @@ BOOL_T need_initialise_frame (NODE_T * p)
 {
   for (TAG_T *tag = ANONYMOUS (TABLE (p)); tag != NO_TAG; FORWARD (tag)) {
     if (PRIO (tag) == ROUTINE_TEXT) {
-      return A68_TRUE;
+      return A68G_TRUE;
     } else if (PRIO (tag) == FORMAT_TEXT) {
-      return A68_TRUE;
+      return A68G_TRUE;
     }
   }
   int count = 0;
   genie_find_proc_op (p, &count);
   if (count > 0) {
-    return A68_TRUE;
+    return A68G_TRUE;
   } else {
-    return A68_FALSE;
+    return A68G_FALSE;
   }
 }
 
@@ -537,9 +537,9 @@ void comment_tree (NODE_T * p, FILE_T out, int *want_space, int *max_print)
 void comment_source (NODE_T * p, FILE_T out)
 {
   int want_space = 0, max_print = 16, ld = -1;
-  undentf (out, a68g_bufprt (A68 (edit_line), SNPRINTF_SIZE, "\n// %s: %d: ", FILENAME (LINE (INFO (p))), LINE_NUMBER (p)));
+  undentf (out, a68g_bufprt (A68G (edit_line), SNPRINTF_SIZE, "\n// %s: %d: ", FILENAME (LINE (INFO (p))), LINE_NUMBER (p)));
   comment_tree (p, out, &want_space, &max_print);
-  tree_listing (out, p, 1, LINE (INFO (p)), &ld, A68_TRUE);
+  tree_listing (out, p, 1, LINE (INFO (p)), &ld, A68G_TRUE);
   undent (out, "\n");
 }
 
@@ -557,18 +557,18 @@ void inline_comment_source (NODE_T * p, FILE_T out)
 
 void write_prelude (FILE_T out)
 {
-  indentf (out, a68g_bufprt (A68 (edit_line), SNPRINTF_SIZE, "// \"%s\" %s\n", FILE_OBJECT_NAME (&A68_JOB), PACKAGE_STRING));
-  indentf (out, a68g_bufprt (A68 (edit_line), SNPRINTF_SIZE, "// optimiser_level=%d code_level=%d\n", OPTION_OPT_LEVEL (&A68_JOB), A68_OPT (OPTION_CODE_LEVEL)));
-  indentf (out, a68g_bufprt (A68 (edit_line), SNPRINTF_SIZE, "// %s %s\n", __DATE__, __TIME__));
-  indentf (out, a68g_bufprt (A68 (edit_line), SNPRINTF_SIZE, "\n#include <%s/a68g-config.h>\n", PACKAGE));
-  indentf (out, a68g_bufprt (A68 (edit_line), SNPRINTF_SIZE, "#include <%s/a68g.h>\n", PACKAGE));
-  indentf (out, a68g_bufprt (A68 (edit_line), SNPRINTF_SIZE, "#include <%s/a68g-genie.h>\n", PACKAGE));
-  indentf (out, a68g_bufprt (A68 (edit_line), SNPRINTF_SIZE, "#include <%s/a68g-prelude.h>\n", PACKAGE));
-  indentf (out, a68g_bufprt (A68 (edit_line), SNPRINTF_SIZE, "#include <%s/a68g-environ.h>\n", PACKAGE));
-  indentf (out, a68g_bufprt (A68 (edit_line), SNPRINTF_SIZE, "#include <%s/a68g-lib.h>\n", PACKAGE));
-  indentf (out, a68g_bufprt (A68 (edit_line), SNPRINTF_SIZE, "#include <%s/a68g-optimiser.h>\n", PACKAGE));
-  indentf (out, a68g_bufprt (A68 (edit_line), SNPRINTF_SIZE, "#include <%s/a68g-frames.h>\n", PACKAGE));
-  indent (out, "\n#define _NODE_(n) (A68 (node_register)[n])\n");
+  indentf (out, a68g_bufprt (A68G (edit_line), SNPRINTF_SIZE, "// \"%s\" %s\n", FILE_OBJECT_NAME (&A68G_JOB), PACKAGE_STRING));
+  indentf (out, a68g_bufprt (A68G (edit_line), SNPRINTF_SIZE, "// optimiser_level=%d code_level=%d\n", OPTION_OPT_LEVEL (&A68G_JOB), A68G_OPT (OPTION_CODE_LEVEL)));
+  indentf (out, a68g_bufprt (A68G (edit_line), SNPRINTF_SIZE, "// %s %s\n", __DATE__, __TIME__));
+  indentf (out, a68g_bufprt (A68G (edit_line), SNPRINTF_SIZE, "\n#include <%s/a68g-config.h>\n", PACKAGE));
+  indentf (out, a68g_bufprt (A68G (edit_line), SNPRINTF_SIZE, "#include <%s/a68g.h>\n", PACKAGE));
+  indentf (out, a68g_bufprt (A68G (edit_line), SNPRINTF_SIZE, "#include <%s/a68g-genie.h>\n", PACKAGE));
+  indentf (out, a68g_bufprt (A68G (edit_line), SNPRINTF_SIZE, "#include <%s/a68g-prelude.h>\n", PACKAGE));
+  indentf (out, a68g_bufprt (A68G (edit_line), SNPRINTF_SIZE, "#include <%s/a68g-environ.h>\n", PACKAGE));
+  indentf (out, a68g_bufprt (A68G (edit_line), SNPRINTF_SIZE, "#include <%s/a68g-lib.h>\n", PACKAGE));
+  indentf (out, a68g_bufprt (A68G (edit_line), SNPRINTF_SIZE, "#include <%s/a68g-optimiser.h>\n", PACKAGE));
+  indentf (out, a68g_bufprt (A68G (edit_line), SNPRINTF_SIZE, "#include <%s/a68g-frames.h>\n", PACKAGE));
+  indent (out, "\n#define _NODE_(n) (A68G (node_register)[n])\n");
   indent (out, "#define _STATUS_(z) (STATUS (z))\n");
   indent (out, "#define _VALUE_(z) (VALUE (z))\n");
 }
@@ -578,13 +578,13 @@ void write_prelude (FILE_T out)
 void init_static_frame (FILE_T out, NODE_T * p)
 {
   if (AP_INCREMENT (TABLE (p)) > 0) {
-    indentf (out, a68g_bufprt (A68 (edit_line), SNPRINTF_SIZE, "FRAME_CLEAR (" A68_LU ");\n", AP_INCREMENT (TABLE (p))));
+    indentf (out, a68g_bufprt (A68G (edit_line), SNPRINTF_SIZE, "FRAME_CLEAR (" A68G_LU ");\n", AP_INCREMENT (TABLE (p))));
   }
-  if (LEX_LEVEL (p) == A68 (global_level)) {
-    indent (out, "A68_GLOBALS = A68_FP;\n");
+  if (LEX_LEVEL (p) == A68G (global_level)) {
+    indent (out, "A68G_GLOBALS = A68G_FP;\n");
   }
   if (need_initialise_frame (p)) {
-    indentf (out, a68g_bufprt (A68 (edit_line), SNPRINTF_SIZE, "initialise_frame (_NODE_ (%d));\n", NUMBER (p)));
+    indentf (out, a68g_bufprt (A68G (edit_line), SNPRINTF_SIZE, "initialise_frame (_NODE_ (%d));\n", NUMBER (p)));
   }
 }
 
@@ -592,14 +592,14 @@ void init_static_frame (FILE_T out, NODE_T * p)
 
 void gen_check_init (NODE_T * p, FILE_T out, char *idf)
 {
-  if (OPTION_COMPILE_CHECK (&A68_JOB) && folder_mode (MOID (p))) {
+  if (OPTION_COMPILE_CHECK (&A68G_JOB) && folder_mode (MOID (p))) {
     if (MOID (p) == M_COMPLEX) {
-      indentf (out, a68g_bufprt (A68 (edit_line), SNPRINTF_SIZE, "if (!(INITIALISED (&(*%s)[0]) && INITIALISED (&(*%s)[1]))) {\n", idf, idf));
-      A68_OPT (indentation)++;
-      indentf (out, a68g_bufprt (A68 (edit_line), SNPRINTF_SIZE, "diagnostic (A68_RUNTIME_ERROR, p, ERROR_EMPTY_VALUE_FROM, M_COMPLEX);\n"));
-      indentf (out, a68g_bufprt (A68 (edit_line), SNPRINTF_SIZE, "exit_genie ((p), A68_RUNTIME_ERROR);\n"));
-      A68_OPT (indentation)--;
-      indentf (out, a68g_bufprt (A68 (edit_line), SNPRINTF_SIZE, "}\n"));
+      indentf (out, a68g_bufprt (A68G (edit_line), SNPRINTF_SIZE, "if (!(INITIALISED (&(*%s)[0]) && INITIALISED (&(*%s)[1]))) {\n", idf, idf));
+      A68G_OPT (indentation)++;
+      indentf (out, a68g_bufprt (A68G (edit_line), SNPRINTF_SIZE, "diagnostic (A68G_RUNTIME_ERROR, p, ERROR_EMPTY_VALUE_FROM, M_COMPLEX);\n"));
+      indentf (out, a68g_bufprt (A68G (edit_line), SNPRINTF_SIZE, "exit_genie ((p), A68G_RUNTIME_ERROR);\n"));
+      A68G_OPT (indentation)--;
+      indentf (out, a68g_bufprt (A68G (edit_line), SNPRINTF_SIZE, "}\n"));
     } else {
       char *M = "M_ERROR";
       if (MOID (p) == M_INT) {
@@ -611,12 +611,12 @@ void gen_check_init (NODE_T * p, FILE_T out, char *idf)
       } else if (MOID (p) == M_CHAR) {
         M = "M_CHAR";
       }
-      indentf (out, a68g_bufprt (A68 (edit_line), SNPRINTF_SIZE, "if (!INITIALISED(%s)) {\n", idf));
-      A68_OPT (indentation)++;
-      indentf (out, a68g_bufprt (A68 (edit_line), SNPRINTF_SIZE, "diagnostic (A68_RUNTIME_ERROR, p, ERROR_EMPTY_VALUE_FROM, %s);\n", M));
-      indentf (out, a68g_bufprt (A68 (edit_line), SNPRINTF_SIZE, "exit_genie ((p), A68_RUNTIME_ERROR);\n"));
-      A68_OPT (indentation)--;
-      indentf (out, a68g_bufprt (A68 (edit_line), SNPRINTF_SIZE, "}\n"));
+      indentf (out, a68g_bufprt (A68G (edit_line), SNPRINTF_SIZE, "if (!INITIALISED(%s)) {\n", idf));
+      A68G_OPT (indentation)++;
+      indentf (out, a68g_bufprt (A68G (edit_line), SNPRINTF_SIZE, "diagnostic (A68G_RUNTIME_ERROR, p, ERROR_EMPTY_VALUE_FROM, %s);\n", M));
+      indentf (out, a68g_bufprt (A68G (edit_line), SNPRINTF_SIZE, "exit_genie ((p), A68G_RUNTIME_ERROR);\n"));
+      A68G_OPT (indentation)--;
+      indentf (out, a68g_bufprt (A68G (edit_line), SNPRINTF_SIZE, "}\n"));
     }
   }
 }
@@ -625,14 +625,14 @@ void gen_check_init (NODE_T * p, FILE_T out, char *idf)
 
 void get_stack (NODE_T * p, FILE_T out, char *dst, char *cast)
 {
-  if (A68_OPT (OPTION_CODE_LEVEL) >= 4) {
-    if (LEVEL (GINFO (p)) == A68 (global_level)) {
-      indentf (out, a68g_bufprt (A68 (edit_line), SNPRINTF_SIZE, "GET_GLOBAL (%s, %s, " A68_LU ");\n", dst, cast, OFFSET (TAX (p))));
+  if (A68G_OPT (OPTION_CODE_LEVEL) >= 4) {
+    if (LEVEL (GINFO (p)) == A68G (global_level)) {
+      indentf (out, a68g_bufprt (A68G (edit_line), SNPRINTF_SIZE, "GET_GLOBAL (%s, %s, " A68G_LU ");\n", dst, cast, OFFSET (TAX (p))));
     } else {
-      indentf (out, a68g_bufprt (A68 (edit_line), SNPRINTF_SIZE, "GET_FRAME (%s, %s, %d, " A68_LU ");\n", dst, cast, LEVEL (GINFO (p)), OFFSET (TAX (p))));
+      indentf (out, a68g_bufprt (A68G (edit_line), SNPRINTF_SIZE, "GET_FRAME (%s, %s, %d, " A68G_LU ");\n", dst, cast, LEVEL (GINFO (p)), OFFSET (TAX (p))));
     }
   } else {
-    indentf (out, a68g_bufprt (A68 (edit_line), SNPRINTF_SIZE, "GET_FRAME (%s, %s, %d, " A68_LU ");\n", dst, cast, LEVEL (GINFO (p)), OFFSET (TAX (p))));
+    indentf (out, a68g_bufprt (A68G (edit_line), SNPRINTF_SIZE, "GET_FRAME (%s, %s, %d, " A68G_LU ");\n", dst, cast, LEVEL (GINFO (p)), OFFSET (TAX (p))));
   }
 }
 
@@ -641,12 +641,12 @@ void get_stack (NODE_T * p, FILE_T out, char *dst, char *cast)
 void write_fun_prelude (NODE_T * p, FILE_T out, char *fn)
 {
   (void) p;
-  indentf (out, a68g_bufprt (A68 (edit_line), SNPRINTF_SIZE, "\nPROP_T %s (NODE_T *p) {\n", fn));
-  A68_OPT (indentation)++;
+  indentf (out, a68g_bufprt (A68G (edit_line), SNPRINTF_SIZE, "\nPROP_T %s (NODE_T *p) {\n", fn));
+  A68G_OPT (indentation)++;
   indent (out, "PROP_T self;\n");
-  indentf (out, a68g_bufprt (A68 (edit_line), SNPRINTF_SIZE, "UNIT (&self) = %s;\n", fn));
-  indentf (out, a68g_bufprt (A68 (edit_line), SNPRINTF_SIZE, "SOURCE (&self) = _NODE_ (%d);\n", NUMBER (p)));
-  A68_OPT (cse_pointer) = 0;
+  indentf (out, a68g_bufprt (A68G (edit_line), SNPRINTF_SIZE, "UNIT (&self) = %s;\n", fn));
+  indentf (out, a68g_bufprt (A68G (edit_line), SNPRINTF_SIZE, "SOURCE (&self) = _NODE_ (%d);\n", NUMBER (p)));
+  A68G_OPT (cse_pointer) = 0;
 }
 
 //! @brief Code function postlude.
@@ -656,10 +656,10 @@ void write_fun_postlude (NODE_T * p, FILE_T out, char *fn)
   (void) fn;
   (void) p;
   indent (out, "return (self);\n");
-  A68_OPT (indentation)--;
-  A68_OPT (procedures)++;
+  A68G_OPT (indentation)--;
+  A68G_OPT (procedures)++;
   indent (out, "}\n");
-  A68_OPT (cse_pointer) = 0;
+  A68G_OPT (cse_pointer) = 0;
 }
 
 //! @brief Code internal a68g mode.
@@ -693,17 +693,17 @@ char *compile_denotation (NODE_T * p, FILE_T out)
     if (MOID (p) == M_INT) {
       char *end;
       UNSIGNED_T z = (UNSIGNED_T) a68g_strtoi (NSYMBOL (p), &end, 10);
-      ASSERT (a68g_bufprt (N, NAME_SIZE, A68_LX "_", z) >= 0);
+      ASSERT (a68g_bufprt (N, NAME_SIZE, A68G_LX "_", z) >= 0);
       (void) make_unic_name (fn, moid_with_name ("", MOID (p), "_denotation"), "", N);
     } else if (MOID (p) == M_REAL) {
-      A68_SP = 0;
+      A68G_SP = 0;
       PUSH_UNION (p, M_REAL);
       push_unit (p);
-      INCREMENT_STACK_POINTER (p, SIZE (M_NUMBER) - (A68_UNION_SIZE + SIZE (M_REAL)));
-      PUSH_VALUE (p, A68_REAL_WIDTH + A68_EXP_WIDTH + 5, A68_INT);
-      PUSH_VALUE (p, A68_REAL_WIDTH, A68_INT);
-      PUSH_VALUE (p, A68_EXP_WIDTH + 1, A68_INT);
-      PUSH_VALUE (p, 3, A68_INT);
+      INCREMENT_STACK_POINTER (p, SIZE (M_NUMBER) - (A68G_UNION_SIZE + SIZE (M_REAL)));
+      PUSH_VALUE (p, A68G_REAL_WIDTH + A68G_EXP_WIDTH + 5, A68G_INT);
+      PUSH_VALUE (p, A68G_REAL_WIDTH, A68G_INT);
+      PUSH_VALUE (p, A68G_EXP_WIDTH + 1, A68G_INT);
+      PUSH_VALUE (p, 3, A68G_INT);
       char *V = real (p);
       char W[NAME_SIZE];
       for (int k = 0; V[0] != '\0'; V++) {
@@ -734,9 +734,9 @@ char *compile_denotation (NODE_T * p, FILE_T out)
         (void) make_name (fn, moid_with_name ("", MOID (p), "_denotation_alt"), "", NUMBER (p));
       }
       write_fun_prelude (p, out, fn);
-      indentf (out, a68g_bufprt (A68 (edit_line), SNPRINTF_SIZE, "PUSH_VALUE (p, "));
+      indentf (out, a68g_bufprt (A68G (edit_line), SNPRINTF_SIZE, "PUSH_VALUE (p, "));
       inline_unit (p, out, L_YIELD);
-      undentf (out, a68g_bufprt (A68 (edit_line), SNPRINTF_SIZE, ", %s);\n", inline_mode (MOID (p))));
+      undentf (out, a68g_bufprt (A68G (edit_line), SNPRINTF_SIZE, ", %s);\n", inline_mode (MOID (p))));
       write_fun_postlude (p, out, fn);
     }
     return fn;
@@ -751,9 +751,9 @@ char *compile_cast (NODE_T * p, FILE_T out)
     static char fn[NAME_SIZE];
     comment_source (p, out);
     (void) make_name (fn, moid_with_name ("", MOID (p), "_cast"), "", NUMBER (p));
-    A68_OPT (root_idf) = NO_DEC;
+    A68G_OPT (root_idf) = NO_DEC;
     inline_unit (NEXT_SUB (p), out, L_DECLARE);
-    print_declarations (out, A68_OPT (root_idf));
+    print_declarations (out, A68G_OPT (root_idf));
     inline_unit (NEXT_SUB (p), out, L_EXECUTE);
     gen_push (NEXT_SUB (p), out);
     return fn;
@@ -772,11 +772,11 @@ char *compile_identifier (NODE_T * p, FILE_T out)
     char N[NAME_SIZE];
 // Some identifiers in standenv cannot be pushed.
 // Examples are cputime, or clock that are procedures in disguise.
-    if (A68_STANDENV_PROC (TAX (p))) {
-      BOOL_T ok = A68_FALSE;
+    if (A68G_STANDENV_PROC (TAX (p))) {
+      BOOL_T ok = A68G_FALSE;
       for (int k = 0; PROCEDURE (&constants[k]) != NO_GPROC; k++) {
         if (PROCEDURE (TAX (p)) == PROCEDURE (&constants[k])) {
-          ok = A68_TRUE;
+          ok = A68G_TRUE;
         }
       }
       if (!ok) {
@@ -784,7 +784,7 @@ char *compile_identifier (NODE_T * p, FILE_T out)
       }
     }
 // Push the identifier.
-    ASSERT (a68g_bufprt (N, NAME_SIZE, "%d_%d_" A68_LU, NUM (TABLE (TAX (p))), LEVEL (GINFO (p)), OFFSET (TAX (p))) >= 0);
+    ASSERT (a68g_bufprt (N, NAME_SIZE, "%d_%d_" A68G_LU, NUM (TABLE (TAX (p))), LEVEL (GINFO (p)), OFFSET (TAX (p))) >= 0);
     comment_source (p, out);
     fn[0] = '\0';
     (void) make_unic_name (fn, moid_with_name ("", MOID (p), "_identifier"), "", N);
@@ -797,9 +797,9 @@ char *compile_identifier (NODE_T * p, FILE_T out)
         (void) make_name (fn, moid_with_name ("", MOID (p), "_identifier_alt"), "", NUMBER (p));
       }
       write_fun_prelude (p, out, fn);
-      A68_OPT (root_idf) = NO_DEC;
+      A68G_OPT (root_idf) = NO_DEC;
       inline_unit (p, out, L_DECLARE);
-      print_declarations (out, A68_OPT (root_idf));
+      print_declarations (out, A68G_OPT (root_idf));
       inline_unit (p, out, L_EXECUTE);
       gen_push (p, out);
       write_fun_postlude (p, out, fn);
@@ -819,7 +819,7 @@ char *compile_dereference_identifier (NODE_T * p, FILE_T out)
     int action = UNIC_MAKE_ALT;
     char N[NAME_SIZE];
     NODE_T *q = SUB (p);
-    ASSERT (a68g_bufprt (N, NAME_SIZE, "%d_%d_" A68_LU, NUM (TABLE (TAX (q))), LEVEL (GINFO (q)), OFFSET (TAX (q))) >= 0);
+    ASSERT (a68g_bufprt (N, NAME_SIZE, "%d_%d_" A68G_LU, NUM (TABLE (TAX (q))), LEVEL (GINFO (q)), OFFSET (TAX (q))) >= 0);
     comment_source (p, out);
     fn[0] = '\0';
     (void) make_unic_name (fn, moid_with_name ("deref_REF_", MOID (p), "_identifier"), "", N);
@@ -832,9 +832,9 @@ char *compile_dereference_identifier (NODE_T * p, FILE_T out)
         (void) make_name (fn, moid_with_name ("deref_REF_", MOID (p), "_identifier_alt"), "", NUMBER (p));
       }
       write_fun_prelude (p, out, fn);
-      A68_OPT (root_idf) = NO_DEC;
+      A68G_OPT (root_idf) = NO_DEC;
       inline_unit (p, out, L_DECLARE);
-      print_declarations (out, A68_OPT (root_idf));
+      print_declarations (out, A68G_OPT (root_idf));
       inline_unit (p, out, L_EXECUTE);
       gen_push (p, out);
       write_fun_postlude (p, out, fn);
@@ -854,36 +854,36 @@ char *compile_formula (NODE_T * p, FILE_T out)
     comment_source (p, out);
     (void) make_name (fn, moid_with_name ("", MOID (p), "_formula"), "", NUMBER (p));
     write_fun_prelude (p, out, fn);
-    if (OPTION_COMPILE_CHECK (&A68_JOB) && !constant_unit (p)) {
+    if (OPTION_COMPILE_CHECK (&A68G_JOB) && !constant_unit (p)) {
       if (MOID (p) == M_REAL || MOID (p) == M_COMPLEX) {
-        indentf (out, a68g_bufprt (A68 (edit_line), SNPRINTF_SIZE, "A68_REAL * _st_ = (A68_REAL *) STACK_TOP;\n"));
+        indentf (out, a68g_bufprt (A68G (edit_line), SNPRINTF_SIZE, "A68G_REAL * _st_ = (A68G_REAL *) STACK_TOP;\n"));
       }
     }
-    A68_OPT (root_idf) = NO_DEC;
+    A68G_OPT (root_idf) = NO_DEC;
     inline_unit (p, out, L_DECLARE);
-    print_declarations (out, A68_OPT (root_idf));
-    if (OPTION_COMPILE_CHECK (&A68_JOB) && !constant_unit (p)) {
+    print_declarations (out, A68G_OPT (root_idf));
+    if (OPTION_COMPILE_CHECK (&A68G_JOB) && !constant_unit (p)) {
       if (folder_mode (MOID (p))) {
-        indentf (out, a68g_bufprt (A68 (edit_line), SNPRINTF_SIZE, "errno = 0;\n"));
+        indentf (out, a68g_bufprt (A68G (edit_line), SNPRINTF_SIZE, "errno = 0;\n"));
       }
     }
     inline_unit (p, out, L_EXECUTE);
     gen_push (p, out);
-    if (OPTION_COMPILE_CHECK (&A68_JOB) && !constant_unit (p)) {
+    if (OPTION_COMPILE_CHECK (&A68G_JOB) && !constant_unit (p)) {
       if (MOID (p) == M_INT) {
-        indentf (out, a68g_bufprt (A68 (edit_line), SNPRINTF_SIZE, "MATH_RTE (p, errno != 0, M_INT, NO_TEXT);\n"));
+        indentf (out, a68g_bufprt (A68G (edit_line), SNPRINTF_SIZE, "MATH_RTE (p, errno != 0, M_INT, NO_TEXT);\n"));
       }
       if (MOID (p) == M_REAL) {
-        indentf (out, a68g_bufprt (A68 (edit_line), SNPRINTF_SIZE, "MATH_RTE (p, errno != 0, M_REAL, NO_TEXT);\n"));
-        indentf (out, a68g_bufprt (A68 (edit_line), SNPRINTF_SIZE, "CHECK_REAL (p, _VALUE_ (_st_));\n"));
+        indentf (out, a68g_bufprt (A68G (edit_line), SNPRINTF_SIZE, "MATH_RTE (p, errno != 0, M_REAL, NO_TEXT);\n"));
+        indentf (out, a68g_bufprt (A68G (edit_line), SNPRINTF_SIZE, "CHECK_REAL (p, _VALUE_ (_st_));\n"));
       }
       if (MOID (p) == M_BITS) {
-        indentf (out, a68g_bufprt (A68 (edit_line), SNPRINTF_SIZE, "MATH_RTE (p, errno != 0, M_BITS, NO_TEXT);\n"));
+        indentf (out, a68g_bufprt (A68G (edit_line), SNPRINTF_SIZE, "MATH_RTE (p, errno != 0, M_BITS, NO_TEXT);\n"));
       }
       if (MOID (p) == M_COMPLEX) {
-        indentf (out, a68g_bufprt (A68 (edit_line), SNPRINTF_SIZE, "MATH_RTE (p, errno != 0, M_COMPLEX, NO_TEXT);\n"));
-        indentf (out, a68g_bufprt (A68 (edit_line), SNPRINTF_SIZE, "CHECK_REAL (p, _VALUE_ (&(_st_[0])));\n"));
-        indentf (out, a68g_bufprt (A68 (edit_line), SNPRINTF_SIZE, "CHECK_REAL (p, _VALUE_ (&(_st_[1])));\n"));
+        indentf (out, a68g_bufprt (A68G (edit_line), SNPRINTF_SIZE, "MATH_RTE (p, errno != 0, M_COMPLEX, NO_TEXT);\n"));
+        indentf (out, a68g_bufprt (A68G (edit_line), SNPRINTF_SIZE, "CHECK_REAL (p, _VALUE_ (&(_st_[0])));\n"));
+        indentf (out, a68g_bufprt (A68G (edit_line), SNPRINTF_SIZE, "CHECK_REAL (p, _VALUE_ (&(_st_[1])));\n"));
       }
     }
     write_fun_postlude (p, out, fn);
@@ -906,15 +906,15 @@ char *compile_call (NODE_T * p, FILE_T out)
     return NO_TEXT;
   } else if (DIM (MOID (proc)) == 0) {
     return NO_TEXT;
-  } else if (A68_STANDENV_PROC (TAX (idf))) {
+  } else if (A68G_STANDENV_PROC (TAX (idf))) {
     if (basic_call (p)) {
       static char fun[NAME_SIZE];
       comment_source (p, out);
       (void) make_name (fun, moid_with_name ("", SUB_MOID (proc), "_call"), "", NUMBER (p));
       write_fun_prelude (p, out, fun);
-      A68_OPT (root_idf) = NO_DEC;
+      A68G_OPT (root_idf) = NO_DEC;
       inline_unit (p, out, L_DECLARE);
-      print_declarations (out, A68_OPT (root_idf));
+      print_declarations (out, A68G_OPT (root_idf));
       inline_unit (p, out, L_EXECUTE);
       gen_push (p, out);
       write_fun_postlude (p, out, fun);
@@ -940,30 +940,30 @@ char *compile_call (NODE_T * p, FILE_T out)
     write_fun_prelude (p, out, fn);
 // Compute arguments.
     size = 0;
-    A68_OPT (root_idf) = NO_DEC;
+    A68G_OPT (root_idf) = NO_DEC;
     inline_arguments (args, out, L_DECLARE, &size);
-    (void) add_declaration (&A68_OPT (root_idf), "ADDR_T", 0, pop);
-    (void) add_declaration (&A68_OPT (root_idf), "A68_PROCEDURE", 1, fun);
-    (void) add_declaration (&A68_OPT (root_idf), "NODE_T", 1, "body");
-    print_declarations (out, A68_OPT (root_idf));
+    (void) add_declaration (&A68G_OPT (root_idf), "ADDR_T", 0, pop);
+    (void) add_declaration (&A68G_OPT (root_idf), "A68G_PROCEDURE", 1, fun);
+    (void) add_declaration (&A68G_OPT (root_idf), "NODE_T", 1, "body");
+    print_declarations (out, A68G_OPT (root_idf));
 // Initialise.
-    indentf (out, a68g_bufprt (A68 (edit_line), SNPRINTF_SIZE, "%s = A68_SP;\n", pop));
+    indentf (out, a68g_bufprt (A68G (edit_line), SNPRINTF_SIZE, "%s = A68G_SP;\n", pop));
     inline_arguments (args, out, L_INITIALISE, &size);
-    get_stack (idf, out, fun, "A68_PROCEDURE");
-    indentf (out, a68g_bufprt (A68 (edit_line), SNPRINTF_SIZE, "body = SUB (NODE (&BODY (%s)));\n", fun));
-    indentf (out, a68g_bufprt (A68 (edit_line), SNPRINTF_SIZE, "OPEN_PROC_FRAME (body, ENVIRON (%s));\n", fun));
-    indentf (out, a68g_bufprt (A68 (edit_line), SNPRINTF_SIZE, "INIT_STATIC_FRAME (body);\n"));
+    get_stack (idf, out, fun, "A68G_PROCEDURE");
+    indentf (out, a68g_bufprt (A68G (edit_line), SNPRINTF_SIZE, "body = SUB (NODE (&BODY (%s)));\n", fun));
+    indentf (out, a68g_bufprt (A68G (edit_line), SNPRINTF_SIZE, "OPEN_PROC_FRAME (body, ENVIRON (%s));\n", fun));
+    indentf (out, a68g_bufprt (A68G (edit_line), SNPRINTF_SIZE, "INIT_STATIC_FRAME (body);\n"));
     size = 0;
     inline_arguments (args, out, L_EXECUTE, &size);
     size = 0;
     inline_arguments (args, out, L_YIELD, &size);
 // Execute procedure.
-    indentf (out, a68g_bufprt (A68 (edit_line), SNPRINTF_SIZE, "A68_SP = %s;\n", pop));
+    indentf (out, a68g_bufprt (A68G (edit_line), SNPRINTF_SIZE, "A68G_SP = %s;\n", pop));
     indent (out, "GENIE_UNIT_TRACE (NEXT_NEXT_NEXT (body));\n");
-    indent (out, "if (A68_FP == A68_MON (finish_frame_pointer)) {\n");
-    A68_OPT (indentation)++;
-    indentf (out, a68g_bufprt (A68 (edit_line), SNPRINTF_SIZE, "change_masks (TOP_NODE (&A68_JOB), BREAKPOINT_INTERRUPT_MASK, A68_TRUE);\n"));
-    A68_OPT (indentation)--;
+    indent (out, "if (A68G_FP == A68G_MON (finish_frame_pointer)) {\n");
+    A68G_OPT (indentation)++;
+    indentf (out, a68g_bufprt (A68G (edit_line), SNPRINTF_SIZE, "change_masks (TOP_NODE (&A68G_JOB), BREAKPOINT_INTERRUPT_MASK, A68G_TRUE);\n"));
+    A68G_OPT (indentation)--;
     indent (out, "}\n");
     indent (out, "CLOSE_FRAME;\n");
     write_fun_postlude (p, out, fn);
