@@ -88,15 +88,15 @@
 
 void genie_gc_heap (NODE_T * p)
 {
-  gc_heap (p, A68_FP);
+  gc_heap (p, A68G_FP);
 }
 
 //! @brief PROC VOID preemptive gc heap
 
 void genie_preemptive_gc_heap (NODE_T * p)
 {
-  if (A68_GC (preemptive)) {
-    gc_heap (p, A68_FP);
+  if (A68G_GC (preemptive)) {
+    gc_heap (p, A68G_FP);
   }
 }
 
@@ -104,28 +104,28 @@ void genie_preemptive_gc_heap (NODE_T * p)
 
 void genie_block (NODE_T * p)
 {
-  PUSH_VALUE (p, 0, A68_INT);
+  PUSH_VALUE (p, 0, A68G_INT);
 }
 
 //! @brief INT garbage collections
 
 void genie_garbage_collections (NODE_T * p)
 {
-  PUSH_VALUE (p, A68_GC (sweeps), A68_INT);
+  PUSH_VALUE (p, A68G_GC (sweeps), A68G_INT);
 }
 
 //! @brief INT garbage refused
 
 void genie_garbage_refused (NODE_T * p)
 {
-  PUSH_VALUE (p, A68_GC (refused), A68_INT);
+  PUSH_VALUE (p, A68G_GC (refused), A68G_INT);
 }
 
 //! @brief LONG INT garbage freed
 
 void genie_garbage_freed (NODE_T * p)
 {
-  PUSH_VALUE (p, A68_GC (total), A68_INT);
+  PUSH_VALUE (p, A68G_GC (total), A68G_INT);
 }
 
 //! @brief REAL garbage seconds
@@ -133,14 +133,14 @@ void genie_garbage_freed (NODE_T * p)
 void genie_garbage_seconds (NODE_T * p)
 {
 // Note that this timing is a rough cut.
-  PUSH_VALUE (p, A68_GC (seconds), A68_REAL);
+  PUSH_VALUE (p, A68G_GC (seconds), A68G_REAL);
 }
 
 //! @brief Size available for an object in the heap.
 
 unt heap_available (void)
 {
-  return A68 (heap_size) - A68_HP;
+  return A68G (heap_size) - A68G_HP;
 }
 
 //! @brief Initialise heap management.
@@ -148,29 +148,29 @@ unt heap_available (void)
 void genie_init_heap (NODE_T * p)
 {
   (void) p;
-  if (A68_HEAP == NO_BYTE) {
-    diagnostic (A68_RUNTIME_ERROR, TOP_NODE (&A68_JOB), ERROR_OUT_OF_CORE);
-    exit_genie (TOP_NODE (&A68_JOB), A68_RUNTIME_ERROR);
+  if (A68G_HEAP == NO_BYTE) {
+    diagnostic (A68G_RUNTIME_ERROR, TOP_NODE (&A68G_JOB), ERROR_OUT_OF_CORE);
+    exit_genie (TOP_NODE (&A68G_JOB), A68G_RUNTIME_ERROR);
   }
-  if (A68_HANDLES == NO_BYTE) {
-    diagnostic (A68_RUNTIME_ERROR, TOP_NODE (&A68_JOB), ERROR_OUT_OF_CORE);
-    exit_genie (TOP_NODE (&A68_JOB), A68_RUNTIME_ERROR);
+  if (A68G_HANDLES == NO_BYTE) {
+    diagnostic (A68G_RUNTIME_ERROR, TOP_NODE (&A68G_JOB), ERROR_OUT_OF_CORE);
+    exit_genie (TOP_NODE (&A68G_JOB), A68G_RUNTIME_ERROR);
   }
-  A68_GC (seconds) = 0;
-  A68_GC (total) = 0;
-  A68_GC (sweeps) = 0;
-  A68_GC (refused) = 0;
-  A68_GC (preemptive) = A68_FALSE;
-  ABEND (A68 (fixed_heap_pointer) >= (A68 (heap_size) - MIN_MEM_SIZE), ERROR_OUT_OF_CORE, __func__);
-  A68_HP = A68 (fixed_heap_pointer);
-  A68 (heap_is_fluid) = A68_FALSE;
+  A68G_GC (seconds) = 0;
+  A68G_GC (total) = 0;
+  A68G_GC (sweeps) = 0;
+  A68G_GC (refused) = 0;
+  A68G_GC (preemptive) = A68G_FALSE;
+  ABEND (A68G (fixed_heap_pointer) >= (A68G (heap_size) - MIN_MEM_SIZE), ERROR_OUT_OF_CORE, __func__);
+  A68G_HP = A68G (fixed_heap_pointer);
+  A68G (heap_is_fluid) = A68G_FALSE;
 // Assign handle space.
-  A68_HANDLE *z = (A68_HANDLE *) A68_HANDLES;
-  A68_GC (available_handles) = z;
-  A68_GC (busy_handles) = NO_HANDLE;
-  int N = (unt) A68 (handle_pool_size) / SIZE_ALIGNED (A68_HANDLE);
-  A68_GC (free_handles) = N;
-  A68_GC (max_handles) = N;
+  A68G_HANDLE *z = (A68G_HANDLE *) A68G_HANDLES;
+  A68G_GC (available_handles) = z;
+  A68G_GC (busy_handles) = NO_HANDLE;
+  int N = (unt) A68G (handle_pool_size) / SIZE_ALIGNED (A68G_HANDLE);
+  A68G_GC (free_handles) = N;
+  A68G_GC (max_handles) = N;
   for (int k = 0; k < N; k++) {
     STATUS (&(z[k])) = NULL_MASK;
     POINTER (&(z[k])) = NO_BYTE;
@@ -185,28 +185,30 @@ void genie_init_heap (NODE_T * p)
 BOOL_T moid_needs_colouring (MOID_T * m)
 {
   if (IS_REF (m)) {
-    return A68_TRUE;
+    return A68G_TRUE;
   } else if (IS (m, PROC_SYMBOL)) {
-    return A68_TRUE;
+    return A68G_TRUE;
   } else if (IS_FLEX (m) || IS_ROW (m)) {
-    return A68_TRUE;
+    return A68G_TRUE;
   } else if (IS_STRUCT (m) || IS_UNION (m)) {
     for (PACK_T *p = PACK (m); p != NO_PACK; FORWARD (p)) {
       if (moid_needs_colouring (MOID (p))) {
-        return A68_TRUE;
+        return A68G_TRUE;
       }
     }
-    return A68_FALSE;
+    return A68G_FALSE;
+  } else if (m == M_SIMPLIN || m == M_SIMPLOUT) {
+    return A68G_TRUE;
   } else {
-    return A68_FALSE;
+    return A68G_FALSE;
   }
 }
 
 //! @brief Colour all elements of a row.
 
-void colour_row_elements (A68_REF * z, MOID_T * m)
+void colour_row_elements (A68G_REF * z, MOID_T * m)
 {
-  A68_ARRAY *arr; A68_TUPLE *tup;
+  A68G_ARRAY *arr; A68G_TUPLE *tup;
   GET_DESCRIPTOR (arr, tup, z);
   if (get_row_size (tup, DIM (arr)) == 0) {
 // Empty rows have a ghost elements.
@@ -215,7 +217,7 @@ void colour_row_elements (A68_REF * z, MOID_T * m)
   } else {
 // The multi-dimensional garbage collector.
     BYTE_T *elem = ADDRESS (&ARRAY (arr));
-    BOOL_T done = A68_FALSE;
+    BOOL_T done = A68G_FALSE;
     initialise_internal_index (tup, DIM (arr));
     while (!done) {
       ADDR_T index = calculate_internal_index (tup, DIM (arr));
@@ -240,7 +242,7 @@ void colour_object (BYTE_T * item, MOID_T * m)
   LOW_STACK_ALERT (NO_NODE);
   if (IS_REF (m)) {
 // REF AMODE colour pointer and object to which it refers.
-    A68_REF *z = (A68_REF *) item;
+    A68G_REF *z = (A68G_REF *) item;
     if (INITIALISED (z) && IS_IN_HEAP (z)) {
       if (STATUS_TEST (REF_HANDLE (z), COOKIE_MASK)) {
         return;
@@ -253,14 +255,14 @@ void colour_object (BYTE_T * item, MOID_T * m)
     }
   } else if (IS_FLEXETY_ROW (m)) {
 // Claim the descriptor and the row itself.
-    A68_REF *z = (A68_REF *) item;
+    A68G_REF *z = (A68G_REF *) item;
     if (INITIALISED (z) && IS_IN_HEAP (z)) {
       if (STATUS_TEST (REF_HANDLE (z), COOKIE_MASK)) {
         return;
       }
 // An array is ALWAYS in the heap.
       STATUS_SET (REF_HANDLE (z), (COOKIE_MASK | COLOUR_MASK));
-      A68_ARRAY *arr; A68_TUPLE *tup;
+      A68G_ARRAY *arr; A68G_TUPLE *tup;
       GET_DESCRIPTOR (arr, tup, z);
       if (REF_HANDLE (&(ARRAY (arr))) != NO_HANDLE) {
 // Assume its initialisation.
@@ -280,19 +282,19 @@ void colour_object (BYTE_T * item, MOID_T * m)
     }
   } else if (IS_UNION (m)) {
 // UNIONs - a united object may contain a value that needs colouring.
-    A68_UNION *z = (A68_UNION *) item;
+    A68G_UNION *z = (A68G_UNION *) item;
     if (INITIALISED (z)) {
       MOID_T *united_moid = (MOID_T *) VALUE (z);
-      colour_object (&item[A68_UNION_SIZE], united_moid);
+      colour_object (&item[A68G_UNION_SIZE], united_moid);
     }
   } else if (IS (m, PROC_SYMBOL)) {
 // PROCs - save a locale and the objects it points to.
-    A68_PROCEDURE *z = (A68_PROCEDURE *) item;
+    A68G_PROCEDURE *z = (A68G_PROCEDURE *) item;
     if (INITIALISED (z) && LOCALE (z) != NO_HANDLE && !(STATUS_TEST (LOCALE (z), COOKIE_MASK))) {
       BYTE_T *u = POINTER (LOCALE (z));
       STATUS_SET (LOCALE (z), (COOKIE_MASK | COLOUR_MASK));
       for (PACK_T *s = PACK (MOID (z)); s != NO_PACK; FORWARD (s)) {
-        if (VALUE ((A68_BOOL *) & u[0]) == A68_TRUE) {
+        if (VALUE ((A68G_BOOL *) & u[0]) == A68G_TRUE) {
           colour_object (&u[SIZE (M_BOOL)], MOID (s));
         }
         u = &(u[SIZE (M_BOOL) + SIZE (MOID (s))]);
@@ -301,10 +303,16 @@ void colour_object (BYTE_T * item, MOID_T * m)
     }
   } else if (m == M_SOUND) {
 // Claim the data of a SOUND object, that is in the heap.
-    A68_SOUND *w = (A68_SOUND *) item;
+    A68G_SOUND *w = (A68G_SOUND *) item;
     if (INITIALISED (w)) {
       STATUS_SET (REF_HANDLE (&(DATA (w))), (COOKIE_MASK | COLOUR_MASK));
     }
+  } else if (m == M_SIMPLIN || m == M_SIMPLOUT) {
+    A68G_UNION *z = (A68G_UNION *) item;
+    if (INITIALISED (z)) {
+      MOID_T *united_moid = (MOID_T *) VALUE (z);
+      colour_object (&item[A68G_UNION_SIZE], united_moid);
+    }
   }
 }
 
@@ -314,15 +322,13 @@ void colour_heap (ADDR_T fp)
 {
   while (fp != 0) {
     NODE_T *p = FRAME_TREE (fp);
-    TABLE_T *q = TABLE (p);
-    if (q != NO_TABLE) {
-      for (TAG_T *i = IDENTIFIERS (q); i != NO_TAG; FORWARD (i)) {
-        colour_object (FRAME_LOCAL (fp, OFFSET (i)), MOID (i));
+    TABLE_T *t = TABLE (p);
+    if (t != NO_TABLE) {
+      for (TAG_T *q = IDENTIFIERS (t); q != NO_TAG; FORWARD (q)) {
+        colour_object (FRAME_LOCAL (fp, OFFSET (q)), MOID (q));
       }
-      for (TAG_T *i = ANONYMOUS (q); i != NO_TAG; FORWARD (i)) {
-        if (PRIO (i) == GENERATOR) {
-          colour_object (FRAME_LOCAL (fp, OFFSET (i)), MOID (i));
-        }
+      for (TAG_T *q = ANONYMOUS (t); q != NO_TAG; FORWARD (q)) {
+        colour_object (FRAME_LOCAL (fp, OFFSET (q)), MOID (q));
       }
     }
     fp = FRAME_DYNAMIC_LINK (fp);
@@ -333,52 +339,52 @@ void colour_heap (ADDR_T fp)
 
 void defragment_heap (void)
 {
-  A68_HANDLE *z;
+  A68G_HANDLE *z;
 // Free handles.
-  z = A68_GC (busy_handles);
+  z = A68G_GC (busy_handles);
   while (z != NO_HANDLE) {
     if (!(STATUS_TEST (z, COLOUR_MASK)) && !(STATUS_TEST (z, BLOCK_GC_MASK))) {
-      A68_HANDLE *y = NEXT (z);
+      A68G_HANDLE *y = NEXT (z);
       if (PREVIOUS (z) == NO_HANDLE) {
-        A68_GC (busy_handles) = NEXT (z);
+        A68G_GC (busy_handles) = NEXT (z);
       } else {
         NEXT (PREVIOUS (z)) = NEXT (z);
       }
       if (NEXT (z) != NO_HANDLE) {
         PREVIOUS (NEXT (z)) = PREVIOUS (z);
       }
-      NEXT (z) = A68_GC (available_handles);
+      NEXT (z) = A68G_GC (available_handles);
       PREVIOUS (z) = NO_HANDLE;
       if (NEXT (z) != NO_HANDLE) {
         PREVIOUS (NEXT (z)) = z;
       }
-      A68_GC (available_handles) = z;
+      A68G_GC (available_handles) = z;
       STATUS_CLEAR (z, ALLOCATED_MASK);
-      A68_GC (freed) += SIZE (z);
-      A68_GC (free_handles)++;
+      A68G_GC (freed) += SIZE (z);
+      A68G_GC (free_handles)++;
       z = y;
     } else {
       FORWARD (z);
     }
   }
 // There can be no uncoloured allocated handle.
-  for (z = A68_GC (busy_handles); z != NO_HANDLE; FORWARD (z)) {
+  for (z = A68G_GC (busy_handles); z != NO_HANDLE; FORWARD (z)) {
     ABEND (!(STATUS_TEST (z, COLOUR_MASK)) && !(STATUS_TEST (z, BLOCK_GC_MASK)), ERROR_INTERNAL_CONSISTENCY, __func__);
   }
 // Defragment the heap.
-  A68_HP = A68 (fixed_heap_pointer);
-  for (z = A68_GC (busy_handles); z != NO_HANDLE && NEXT (z) != NO_HANDLE; FORWARD (z)) {
+  A68G_HP = A68G (fixed_heap_pointer);
+  for (z = A68G_GC (busy_handles); z != NO_HANDLE && NEXT (z) != NO_HANDLE; FORWARD (z)) {
     ;
   }
   for (; z != NO_HANDLE; BACKWARD (z)) {
-    BYTE_T *dst = HEAP_ADDRESS (A68_HP);
+    BYTE_T *dst = HEAP_ADDRESS (A68G_HP);
     if (dst != POINTER (z)) {
       MOVE (dst, POINTER (z), (unt) SIZE (z));
     }
     STATUS_CLEAR (z, (COLOUR_MASK | COOKIE_MASK));
     POINTER (z) = dst;
-    A68_HP += (SIZE (z));
-    ABEND (A68_HP % A68_ALIGNMENT != 0, ERROR_ALIGNMENT, __func__);
+    A68G_HP += (SIZE (z));
+    ABEND (A68G_HP % A68G_ALIGNMENT != 0, ERROR_ALIGNMENT, __func__);
   }
 }
 
@@ -387,139 +393,143 @@ void defragment_heap (void)
 void gc_heap (NODE_T * p, ADDR_T fp)
 {
 // Must start with fp = current frame_pointer.
-  A68_HANDLE *z;
+  A68G_HANDLE *z;
   REAL_T t0, t1;
 #if defined (BUILD_PARALLEL_CLAUSE)
-  if (OTHER_THREAD (FRAME_THREAD_ID (A68_FP), A68_PAR (main_thread_id))) {
-    A68_GC (refused)++;
+  if (OTHER_THREAD (FRAME_THREAD_ID (A68G_FP), A68G_PAR (main_thread_id))) {
+    A68G_GC (refused)++;
     return;
   }
 #endif
-  if (STATUS_TEST (p, BLOCK_GC_MASK) || A68_GC (sema) > 0) {
-    A68_GC (refused)++;
+  if (STATUS_TEST (p, BLOCK_GC_MASK)) {
+    A68G_GC (refused)++;
+    return;
+  }
+  if (OPTION_CONSERVATIVE_GC (&A68G_JOB) && (A68G_GC (sema) > 0)) {
+    A68G_GC (refused)++;
     return;
   }
 // Take no risk when intermediate results are on the stack.
-  if (A68_SP != A68 (stack_start)) {
-    A68_GC (refused)++;
+  if (OPTION_CONSERVATIVE_GC (&A68G_JOB) && (A68G_SP != A68G (stack_start))) {
+    A68G_GC (refused)++;
     return;
   }
 // Give it a whirl then.
   t0 = seconds ();
 // Unfree handles are subject to inspection.
 // Release them all before colouring.
-  for (z = A68_GC (busy_handles); z != NO_HANDLE; FORWARD (z)) {
+  for (z = A68G_GC (busy_handles); z != NO_HANDLE; FORWARD (z)) {
     STATUS_CLEAR (z, (COLOUR_MASK | COOKIE_MASK));
   }
 // Pour paint into the heap to reveal active objects.
   colour_heap (fp);
 // Start freeing and compacting.
-  A68_GC (freed) = 0;
+  A68G_GC (freed) = 0;
   defragment_heap ();
 // Stats and logging.
-  A68_GC (total) += A68_GC (freed);
-  A68_GC (sweeps)++;
-  A68_GC (preemptive) = A68_FALSE;
+  A68G_GC (total) += A68G_GC (freed);
+  A68G_GC (sweeps)++;
+  A68G_GC (preemptive) = A68G_FALSE;
   t1 = seconds ();
 // C optimiser can make last digit differ, so next condition is 
 // needed to determine a positive time difference
-  if ((t1 - t0) > ((REAL_T) A68 (clock_res) / 2.0)) {
-    A68_GC (seconds) += (t1 - t0);
+  if ((t1 - t0) > ((REAL_T) A68G (clock_res) / 2.0)) {
+    A68G_GC (seconds) += (t1 - t0);
   } else {
-    A68_GC (seconds) += ((REAL_T) A68 (clock_res) / 2.0);
+    A68G_GC (seconds) += ((REAL_T) A68G (clock_res) / 2.0);
   }
 // Call the event handler.
-  genie_call_event_routine (p, M_PROC_VOID, &A68 (on_gc_event), A68_SP, A68_FP);
+  genie_call_event_routine (p, M_PROC_VOID, &A68G (on_gc_event), A68G_SP, A68G_FP);
 }
 
 //! @brief Yield a handle that will point to a block in the heap.
 
-A68_HANDLE *give_handle (NODE_T * p, MOID_T * a68m)
+A68G_HANDLE *give_handle (NODE_T * p, MOID_T * a68m)
 {
-  if (A68_GC (available_handles) != NO_HANDLE) {
-    A68_HANDLE *x = A68_GC (available_handles);
-    A68_GC (available_handles) = NEXT (x);
-    if (A68_GC (available_handles) != NO_HANDLE) {
-      PREVIOUS (A68_GC (available_handles)) = NO_HANDLE;
+  if (A68G_GC (available_handles) != NO_HANDLE) {
+    A68G_HANDLE *x = A68G_GC (available_handles);
+    A68G_GC (available_handles) = NEXT (x);
+    if (A68G_GC (available_handles) != NO_HANDLE) {
+      PREVIOUS (A68G_GC (available_handles)) = NO_HANDLE;
     }
     STATUS (x) = ALLOCATED_MASK;
     POINTER (x) = NO_BYTE;
     SIZE (x) = 0;
     MOID (x) = a68m;
-    NEXT (x) = A68_GC (busy_handles);
+    NEXT (x) = A68G_GC (busy_handles);
     PREVIOUS (x) = NO_HANDLE;
     if (NEXT (x) != NO_HANDLE) {
       PREVIOUS (NEXT (x)) = x;
     }
-    A68_GC (busy_handles) = x;
-    A68_GC (free_handles)--;
+    A68G_GC (busy_handles) = x;
+    A68G_GC (free_handles)--;
     return x;
   } else {
 // Do not auto-GC!.
-    diagnostic (A68_RUNTIME_ERROR, p, ERROR_OUT_OF_CORE);
-    exit_genie (p, A68_RUNTIME_ERROR);
+    diagnostic (A68G_RUNTIME_ERROR, p, ERROR_OUT_OF_CORE);
+    exit_genie (p, A68G_RUNTIME_ERROR);
   }
   return NO_HANDLE;
 }
 
 //! @brief Give a block of heap for an object of indicated mode.
 
-A68_REF heap_generator (NODE_T * p, MOID_T * mode, int size)
+A68G_REF heap_generator (NODE_T * p, MOID_T * mode, int size)
 {
   ABEND (size < 0, ERROR_INVALID_SIZE, __func__);
-  size = A68_ALIGN (size);
+  size = A68G_ALIGN (size);
   if (heap_available () >= size) {
-    A68_REF z;
+    A68G_REF z;
     STATUS (&z) = (STATUS_MASK_T) (INIT_MASK | IN_HEAP_MASK);
     OFFSET (&z) = 0;
-    A68_HANDLE *x = give_handle (p, mode);
+    A68G_HANDLE *x = give_handle (p, mode);
     SIZE (x) = size;
-    POINTER (x) = HEAP_ADDRESS (A68_HP);
+    POINTER (x) = HEAP_ADDRESS (A68G_HP);
     FILL (POINTER (x), 0, size);
     REF_SCOPE (&z) = PRIMAL_SCOPE;
     REF_HANDLE (&z) = x;
-    ABEND (((long) ADDRESS (&z)) % A68_ALIGNMENT != 0, ERROR_ALIGNMENT, __func__);
-    A68_HP += size;
-    REAL_T _f_ = (REAL_T) A68_HP / (REAL_T) A68 (heap_size);
-    REAL_T _g_ = (REAL_T) (A68_GC (max_handles) - A68_GC (free_handles)) / (REAL_T) A68_GC (max_handles);
+    ABEND (((long) ADDRESS (&z)) % A68G_ALIGNMENT != 0, ERROR_ALIGNMENT, __func__);
+    A68G_HP += size;
+    REAL_T _f_ = (REAL_T) A68G_HP / (REAL_T) A68G (heap_size);
+    REAL_T _g_ = (REAL_T) (A68G_GC (max_handles) - A68G_GC (free_handles)) / (REAL_T) A68G_GC (max_handles);
     if (_f_ > DEFAULT_PREEMPTIVE || _g_ > DEFAULT_PREEMPTIVE) {
-      A68_GC (preemptive) = A68_TRUE;
+      A68G_GC (preemptive) = A68G_TRUE;
     }
     return z;
   } else {
 // Do not auto-GC!.
-    diagnostic (A68_RUNTIME_ERROR, p, ERROR_OUT_OF_CORE);
-    exit_genie (p, A68_RUNTIME_ERROR);
+    diagnostic (A68G_RUNTIME_ERROR, p, ERROR_OUT_OF_CORE);
+    exit_genie (p, A68G_RUNTIME_ERROR);
     return nil_ref;
   }
 }
 
 //! @brief Give a block of heap for an object of indicated mode.
 
-A68_REF heap_generator_2 (NODE_T * p, MOID_T * mode, int len, int size)
+A68G_REF heap_generator_2 (NODE_T * p, MOID_T * mode, int len, int size)
 {
   if (len == 0 || size == 0) {
     return heap_generator (p, mode, 0);
   } else if (ABS (size) < (2 * GIGABYTE) / ABS (len)) {
     return heap_generator (p, mode, len * size);
   } else {
-    diagnostic (A68_RUNTIME_ERROR, p, ERROR_OUT_OF_CORE);
-    exit_genie (p, A68_RUNTIME_ERROR);
+    diagnostic (A68G_RUNTIME_ERROR, p, ERROR_OUT_OF_CORE);
+    exit_genie (p, A68G_RUNTIME_ERROR);
   }
   return nil_ref;
 }
 
 //! @brief Give a block of heap for an object of indicated mode.
 
-A68_REF heap_generator_3 (NODE_T * p, MOID_T * mode, int len1, int len2, int size)
+A68G_REF heap_generator_3 (NODE_T * p, MOID_T * mode, int len1, int len2, int size)
 {
   if (len1 == 0 || len2 == 0) {
     return heap_generator (p, mode, 0);
   } else if (ABS (len2) < (2 * GIGABYTE) / ABS (len1)) {
     return heap_generator_2 (p, mode, len1 * len2, size);
   } else {
-    diagnostic (A68_RUNTIME_ERROR, p, ERROR_OUT_OF_CORE);
-    exit_genie (p, A68_RUNTIME_ERROR);
+    diagnostic (A68G_RUNTIME_ERROR, p, ERROR_OUT_OF_CORE);
+    exit_genie (p, A68G_RUNTIME_ERROR);
   }
   return nil_ref;
 }
@@ -531,7 +541,7 @@ A68_REF heap_generator_3 (NODE_T * p, MOID_T * mode, int len1, int len2, int siz
 BOOL_T mode_needs_allocation (MOID_T * m)
 {
   if (IS_UNION (m)) {
-    return A68_FALSE;
+    return A68G_FALSE;
   } else {
     return HAS_ROWS (m);
   }
@@ -552,7 +562,7 @@ void genie_compute_bounds (NODE_T * p)
         p = NEXT_NEXT (p);
       } else {
 // Default lower bound.
-        PUSH_VALUE (p, 1, A68_INT);
+        PUSH_VALUE (p, 1, A68G_INT);
       }
       GENIE_UNIT (p);
     }
@@ -631,7 +641,7 @@ void genie_generator_stowed (NODE_T * p, BYTE_T * addr, NODE_T ** decl, ADDR_T *
     return;
   } else if (IS (p, INDICANT) && IS_LITERALLY (p, "STRING")) {
 // The standard prelude definition is hard coded here.
-    *((A68_REF *) addr) = empty_string (p);
+    *((A68G_REF *) addr) = empty_string (p);
     return;
   } else if (IS (p, INDICANT) && TAX (p) != NO_TAG) {
 // Continue from definition at MODE A = ..
@@ -648,28 +658,28 @@ void genie_generator_stowed (NODE_T * p, BYTE_T * addr, NODE_T ** decl, ADDR_T *
     genie_generator_stowed (NEXT (p), addr, decl, cur_sp);
     return;
   } else if (IS (p, BOUNDS)) {
-    A68_REF desc;
+    A68G_REF desc;
     MOID_T *rmod = MOID (p), *smod = MOID (NEXT (p));
     BYTE_T *bounds = STACK_ADDRESS (*cur_sp);
     int dim = DIM (DEFLEX (rmod)), esiz = SIZE (smod), rsiz = 1;
-    BOOL_T alloc_sub = A68_FALSE, alloc_str = A68_FALSE;
+    BOOL_T alloc_sub = A68G_FALSE, alloc_str = A68G_FALSE;
     NODE_T *in = SUB_NEXT (p);
     if (IS (in, INDICANT) && IS_LITERALLY (in, "STRING")) {
-      alloc_str = A68_TRUE;
-      alloc_sub = A68_FALSE;
+      alloc_str = A68G_TRUE;
+      alloc_sub = A68G_FALSE;
     } else {
       alloc_sub = mode_needs_allocation (smod);
-      alloc_str = A68_FALSE;
+      alloc_str = A68G_FALSE;
     }
     desc = heap_generator (p, rmod, DESCRIPTOR_SIZE (dim));
-    A68_ARRAY *arr; A68_TUPLE *tup;
+    A68G_ARRAY *arr; A68G_TUPLE *tup;
     GET_DESCRIPTOR (arr, tup, &desc);
     for (int k = 0; k < dim; k++) {
-      CHECK_INIT (p, INITIALISED ((A68_INT *) bounds), M_INT);
-      LWB (&tup[k]) = VALUE ((A68_INT *) bounds);
+      CHECK_INIT (p, INITIALISED ((A68G_INT *) bounds), M_INT);
+      LWB (&tup[k]) = VALUE ((A68G_INT *) bounds);
       bounds += SIZE (M_INT);
-      CHECK_INIT (p, INITIALISED ((A68_INT *) bounds), M_INT);
-      UPB (&tup[k]) = VALUE ((A68_INT *) bounds);
+      CHECK_INIT (p, INITIALISED ((A68G_INT *) bounds), M_INT);
+      UPB (&tup[k]) = VALUE ((A68G_INT *) bounds);
       bounds += SIZE (M_INT);
       SPAN (&tup[k]) = rsiz;
       SHIFT (&tup[k]) = LWB (&tup[k]) * SPAN (&tup[k]);
@@ -692,7 +702,7 @@ void genie_generator_stowed (NODE_T * p, BYTE_T * addr, NODE_T ** decl, ADDR_T *
         genie_generator_stowed (NEXT (p), &(elem[0]), NO_REF, cur_sp);
         top_sp = *cur_sp;
       } else if (alloc_str) {
-        *(A68_REF *) elem = empty_string (p);
+        *(A68G_REF *) elem = empty_string (p);
       }
       (*cur_sp) = top_sp;
     } else {
@@ -705,12 +715,12 @@ void genie_generator_stowed (NODE_T * p, BYTE_T * addr, NODE_T ** decl, ADDR_T *
           genie_generator_stowed (NEXT (p), &(elem[k * esiz]), NO_REF, cur_sp);
           top_sp = *cur_sp;
         } else if (alloc_str) {
-          *(A68_REF *) (&(elem[k * esiz])) = empty_string (p);
+          *(A68G_REF *) (&(elem[k * esiz])) = empty_string (p);
         }
       }
       (*cur_sp) = top_sp;
     }
-    *(A68_REF *) addr = desc;
+    *(A68G_REF *) addr = desc;
     return;
   }
 }
@@ -721,12 +731,12 @@ void genie_generator_internal (NODE_T * p, MOID_T * ref_mode, TAG_T * tag, LEAP_
 {
 // Set up a REF MODE object, either in the stack or in the heap.
   MOID_T *mode = SUB (ref_mode);
-  A68_REF name = nil_ref;
+  A68G_REF name = nil_ref;
   if (leap == LOC_SYMBOL) {
     STATUS (&name) = (STATUS_MASK_T) (INIT_MASK | IN_FRAME_MASK);
-    REF_HANDLE (&name) = (A68_HANDLE *) & nil_handle;
-    OFFSET (&name) = A68_FP + FRAME_INFO_SIZE + OFFSET (tag);
-    REF_SCOPE (&name) = A68_FP;
+    REF_HANDLE (&name) = (A68G_HANDLE *) & nil_handle;
+    OFFSET (&name) = A68G_FP + FRAME_INFO_SIZE + OFFSET (tag);
+    REF_SCOPE (&name) = A68G_FP;
   } else if (leap == -LOC_SYMBOL && NON_LOCAL (p) != NO_TABLE) {
     name = heap_generator (p, mode, SIZE (mode));
     ADDR_T lev;
@@ -734,7 +744,7 @@ void genie_generator_internal (NODE_T * p, MOID_T * ref_mode, TAG_T * tag, LEAP_
     REF_SCOPE (&name) = lev;
   } else if (leap == -LOC_SYMBOL) {
     name = heap_generator (p, mode, SIZE (mode));
-    REF_SCOPE (&name) = A68_FP;
+    REF_SCOPE (&name) = A68G_FP;
   } else if (leap == HEAP_SYMBOL || leap == -HEAP_SYMBOL) {
     name = heap_generator (p, mode, SIZE (mode));
     REF_SCOPE (&name) = PRIMAL_SCOPE;
@@ -742,7 +752,7 @@ void genie_generator_internal (NODE_T * p, MOID_T * ref_mode, TAG_T * tag, LEAP_
     name = heap_generator (p, mode, SIZE (mode));
     REF_SCOPE (&name) = PRIMAL_SCOPE;
   } else {
-    ABEND (A68_TRUE, ERROR_INTERNAL_CONSISTENCY, __func__);
+    ABEND (A68G_TRUE, ERROR_INTERNAL_CONSISTENCY, __func__);
   }
   if (HAS_ROWS (mode)) {
     ADDR_T cur_sp = sp;
@@ -755,14 +765,14 @@ void genie_generator_internal (NODE_T * p, MOID_T * ref_mode, TAG_T * tag, LEAP_
 
 PROP_T genie_generator (NODE_T * p)
 {
-  ADDR_T pop_sp = A68_SP;
+  ADDR_T pop_sp = A68G_SP;
   if (NEXT_SUB (p) != NO_NODE) {
     genie_generator_bounds (NEXT_SUB (p));
   }
   genie_generator_internal (NEXT_SUB (p), MOID (p), TAX (p), -ATTRIBUTE (SUB (p)), pop_sp);
-  A68_REF z;
+  A68G_REF z;
   POP_REF (p, &z);
-  A68_SP = pop_sp;
+  A68G_SP = pop_sp;
   PUSH_REF (p, z);
   PROP_T self;
   UNIT (&self) = genie_generator;
@@ -776,7 +786,7 @@ PROP_T genie_generator (NODE_T * p)
 
 void discard_heap (void)
 {
-  a68g_free (A68_HEAP);
-  A68 (fixed_heap_pointer) = 0;
-  A68 (temp_heap_pointer) = 0;
+  a68g_free (A68G_HEAP);
+  A68G (fixed_heap_pointer) = 0;
+  A68G (temp_heap_pointer) = 0;
 }
