@@ -47,7 +47,7 @@ struct MODULE_T
 };
 
 typedef struct MODE_CACHE_T MODE_CACHE_T;
-#define MODE(p)        A68 (a68g_modes.p)
+#define MODE(p)        A68G (a68g_modes.p)
 struct MODE_CACHE_T
 {
   MOID_T *proc_bool;
@@ -81,7 +81,7 @@ struct FILE_ENTRY
   NODE_T *pos;
   BOOL_T is_open, is_tmp;
   FILE_T fd;
-  A68_REF idf;
+  A68G_REF idf;
 };
 
 // Administration for common (sub) expression elimination.
@@ -106,31 +106,31 @@ struct UNIC_T
 };
 
 
-#define A68(z)         (common.z)
-#define A68_JOB        A68 (job)
-#define A68_STANDENV   A68 (standenv)
-#define A68_MCACHE(z)  A68 (mode_cache.z)
+#define A68G(z)        (common.z)
+#define A68G_JOB        A68G (job)
+#define A68G_STANDENV   A68G (standenv)
+#define A68G_MCACHE(z)  A68G (mode_cache.z)
 
-#define A68_SP         A68 (stack_pointer)
-#define A68_FP         A68 (frame_pointer)
-#define A68_HP         A68 (heap_pointer)
-#define A68_GLOBALS    A68 (global_pointer)
-#define A68_STACK      A68 (stack_segment)
-#define A68_HEAP       A68 (heap_segment)
-#define A68_HANDLES    A68 (handle_segment)
+#define A68G_SP         A68G (stack_pointer)
+#define A68G_FP         A68G (frame_pointer)
+#define A68G_HP         A68G (heap_pointer)
+#define A68G_GLOBALS    A68G (global_pointer)
+#define A68G_STACK      A68G (stack_segment)
+#define A68G_HEAP       A68G (heap_segment)
+#define A68G_HANDLES    A68G (handle_segment)
 
 typedef struct GC_GLOBALS_T GC_GLOBALS_T;
-#define A68_GC(z)      A68 (gc.z)
+#define A68G_GC(z)      A68G (gc.z)
 struct GC_GLOBALS_T
 {
-  A68_HANDLE *available_handles, *busy_handles;
+  A68G_HANDLE *available_handles, *busy_handles;
   UNSIGNED_T free_handles, max_handles, sweeps, refused, freed, total;
   unt preemptive, sema;
   REAL_T seconds;
 };
 
 typedef struct INDENT_GLOBALS_T INDENT_GLOBALS_T;
-#define A68_INDENT(z)  A68 (indent.z)
+#define A68G_INDENT(z)  A68G (indent.z)
 struct INDENT_GLOBALS_T
 {
   FILE_T fd;
@@ -142,7 +142,7 @@ struct INDENT_GLOBALS_T
 #define MON_STACK_SIZE 32
 
 typedef struct MONITOR_GLOBALS_T MONITOR_GLOBALS_T;
-#define A68_MON(z)     A68 (mon.z)
+#define A68G_MON(z)     A68G (mon.z)
 struct MONITOR_GLOBALS_T
 {
   ADDR_T finish_frame_pointer;
@@ -161,7 +161,7 @@ struct MONITOR_GLOBALS_T
 };
 
 typedef struct MP_GLOBALS_T MP_GLOBALS_T;
-#define A68_MP(z)      A68 (mp.z)
+#define A68G_MP(z)      A68G (mp.z)
 
 struct MP_GLOBALS_T
 {
@@ -189,7 +189,7 @@ struct MP_GLOBALS_T
 #define MAX_UNIC 2048
 
 typedef struct OPTIMISER_GLOBALS_T OPTIMISER_GLOBALS_T;
-#define A68_OPT(z)     A68 (optimiser.z)
+#define A68G_OPT(z)     A68G (optimiser.z)
 struct OPTIMISER_GLOBALS_T
 {
   BOOK_T cse_book[MAX_BOOK];
@@ -206,19 +206,19 @@ struct OPTIMISER_GLOBALS_T
 
 #if defined (BUILD_PARALLEL_CLAUSE)
 
-typedef struct A68_STACK_DESCRIPTOR A68_STACK_DESCRIPTOR;
-typedef struct A68_THREAD_CONTEXT A68_THREAD_CONTEXT;
+typedef struct A68G_STACK_DESCRIPTOR A68G_STACK_DESCRIPTOR;
+typedef struct A68G_THREAD_CONTEXT A68G_THREAD_CONTEXT;
 
-struct A68_STACK_DESCRIPTOR
+struct A68G_STACK_DESCRIPTOR
 {
   ADDR_T cur_ptr, ini_ptr;
   BYTE_T *swap, *start;
   int bytes;
 };
 
-struct A68_THREAD_CONTEXT
+struct A68G_THREAD_CONTEXT
 {
-  A68_STACK_DESCRIPTOR stack, frame;
+  A68G_STACK_DESCRIPTOR stack, frame;
   BOOL_T active;
   BYTE_T *thread_stack_offset;
   int stack_used;
@@ -242,10 +242,10 @@ struct A68_THREAD_CONTEXT
 #endif
 
 typedef struct PARALLEL_GLOBALS_T PARALLEL_GLOBALS_T;
-#define A68_PAR(z)     A68 (parallel.z)
+#define A68G_PAR(z)     A68G (parallel.z)
 struct PARALLEL_GLOBALS_T
 {
-  A68_THREAD_CONTEXT context[THREAD_MAX];
+  A68G_THREAD_CONTEXT context[THREAD_MAX];
   ADDR_T fp0, sp0;
   BOOL_T abend_all_threads, exit_from_threads;
   int context_index;
@@ -260,7 +260,7 @@ struct PARALLEL_GLOBALS_T
 #endif
 
 typedef struct PARSER_GLOBALS_T PARSER_GLOBALS_T;
-#define A68_PARSER(z)  A68 (parser.z)
+#define A68G_PARSER(z)  A68G (parser.z)
 struct PARSER_GLOBALS_T
 {
   TAG_T *error_tag;
@@ -276,10 +276,10 @@ typedef struct GLOBALS_T GLOBALS_T;
 
 struct GLOBALS_T
 {
-  A68_CHANNEL stand_draw_channel, stand_error_channel, associate_channel, skip_channel;
-  A68_CHANNEL stand_in_channel, stand_out_channel, stand_back_channel;
-  A68_PROCEDURE on_gc_event;
-  A68_REF stand_in, stand_out, stand_back, stand_error, skip_file;
+  A68G_CHANNEL stand_draw_channel, stand_error_channel, associate_channel, skip_channel;
+  A68G_CHANNEL stand_in_channel, stand_out_channel, stand_back_channel;
+  A68G_PROCEDURE on_gc_event;
+  A68G_REF stand_in, stand_out, stand_back, stand_error, skip_file;
   ADDR_T fixed_heap_pointer, temp_heap_pointer;
   ADDR_T frame_pointer, stack_pointer, heap_pointer, global_pointer;
   ADDR_T frame_start, frame_end, stack_start, stack_end;
@@ -324,6 +324,7 @@ struct GLOBALS_T
   PARSER_GLOBALS_T parser;
   POSTULATE_T *postulates, *top_postulate, *top_postulate_list;
   REAL_T cputime_0;
+  REAL_T walltime_0;
   SOID_T *top_soid_list;
   TABLE_T *standenv;
   TAG_T *error_tag;
