@@ -32,8 +32,8 @@
 #define MEGABYTE (KILOBYTE * KILOBYTE)
 #define GIGABYTE (KILOBYTE * MEGABYTE)
 
-#define A68_TRUE ((BOOL_T) 1)
-#define A68_FALSE ((BOOL_T) 0)
+#define A68G_TRUE ((BOOL_T) 1)
+#define A68G_FALSE ((BOOL_T) 0)
 
 #define BACKSLASH_CHAR '\\'
 #define BLANK_CHAR ' '
@@ -67,7 +67,7 @@
 // 
 // -Wno-parentheses-equality is needed for OpenBSD.  
 
-#define A68_GCC_OPTIONS "-DA68_OPTIMISE -ggdb -fno-stack-protector -Wno-parentheses-equality"
+#define A68G_GCC_OPTIONS "-DA68G_OPTIMISE -ggdb -fno-stack-protector -Wno-parentheses-equality"
 
 // Formats
 #define DIGIT_BLANK ((unt) 0x2)
@@ -77,16 +77,16 @@
 
 #define MAX_RESTART 256
 
-#define A68_DIR ".a68g"
-#define A68_HISTORY_FILE ".a68g.edit.hist"
-#define A68_NO_FILE ((FILE_T) -1)
-#define A68_PROTECTION (S_IRUSR | S_IWUSR | S_IRGRP | S_IROTH)  // -rw-r--r--
-#define A68_READ_ACCESS (O_RDONLY)
-#define A68_WRITE_ACCESS (O_WRONLY | O_CREAT | O_TRUNC)
+#define A68G_DIR ".a68g"
+#define A68G_HISTORY_FILE ".a68g.edit.hist"
+#define A68G_NO_FILE ((FILE_T) -1)
+#define A68G_PROTECTION (S_IRUSR | S_IWUSR | S_IRGRP | S_IROTH)  // -rw-r--r--
+#define A68G_READ_ACCESS (O_RDONLY)
+#define A68G_WRITE_ACCESS (O_WRONLY | O_CREAT | O_TRUNC)
 #define BUFFER_SIZE (KILOBYTE)
 #define DEFAULT_WIDTH (-1)
 
-#define EMBEDDED_FORMAT A68_TRUE
+#define EMBEDDED_FORMAT A68G_TRUE
 #define EVEN(k) ((k) % 2 == 0)
 #define HIDDEN_TEMP_FILE_NAME ".a68g.tmp"
 #define INTERRUPT_INTERVAL 5
@@ -101,15 +101,15 @@
 #define MONADS "%^&+-~!?"
 #define NEWLINE_STRING "\n"
 #define NOMADS "></=*"
-#define NOT_EMBEDDED_FORMAT A68_FALSE
+#define NOT_EMBEDDED_FORMAT A68G_FALSE
 #define NOT_PRINTED 1
 #define OVER_2G(n) ((REAL_T) (n) > (REAL_T) (2 * GIGABYTE)) 
 #define PRIMAL_SCOPE 0
-#define SKIP_PATTERN A68_FALSE
+#define SKIP_PATTERN A68G_FALSE
 #define SMALL_BUFFER_SIZE 128
 #define SNPRINTF_SIZE ((size_t) (BUFFER_SIZE - 1))
 #define TRANSPUT_BUFFER_SIZE BUFFER_SIZE
-#define WANT_PATTERN A68_TRUE
+#define WANT_PATTERN A68G_TRUE
 
 // Macros
 
@@ -130,8 +130,8 @@
   while (_m_k--) {*_m_u++ = *_m_v++;}}
 
 #define COPY_ALIGNED(d, s, n) {\
-  int _m_k = (n); A68_ALIGN_T *_m_u = (A68_ALIGN_T *) (d), *_m_v = (A68_ALIGN_T *) (s);\
-  while (_m_k > 0) {*_m_u++ = *_m_v++; _m_k -= A68_ALIGNMENT;}}
+  int _m_k = (n); A68G_ALIGN_T *_m_u = (A68G_ALIGN_T *) (d), *_m_v = (A68G_ALIGN_T *) (s);\
+  while (_m_k > 0) {*_m_u++ = *_m_v++; _m_k -= A68G_ALIGNMENT;}}
 
 #define MOVE(d, s, n) {\
   int _m_k = (int) (n); BYTE_T *_m_d = (BYTE_T *) (d), *_m_s = (BYTE_T *) (s);\
@@ -147,8 +147,8 @@
    while (_m_k--) {*_m_u++ = _m_v;}}
 
 #define FILL_ALIGNED(d, s, n) {\
-   int _m_k = (n); A68_ALIGN_T *_m_u = (A68_ALIGN_T *) (d), _m_v = (A68_ALIGN_T) (s);\
-   while (_m_k > 0) {*_m_u++ = _m_v; _m_k -= A68_ALIGNMENT;}}
+   int _m_k = (n); A68G_ALIGN_T *_m_u = (A68G_ALIGN_T *) (d), _m_v = (A68G_ALIGN_T) (s);\
+   while (_m_k > 0) {*_m_u++ = _m_v; _m_k -= A68G_ALIGNMENT;}}
 
 #define ABEND(p, reason, info) {\
   if (p) {\
@@ -158,12 +158,12 @@
 #if defined (HAVE_CURSES)
 #define ASSERT(f) {\
   if (!(f)) {\
-    if (A68 (curses_mode) == A68_TRUE) {\
+    if (A68G (curses_mode) == A68G_TRUE) {\
       (void) attrset (A_NORMAL);\
       (void) endwin ();\
-      A68 (curses_mode) = A68_FALSE;\
+      A68G (curses_mode) = A68G_FALSE;\
     }\
-    ABEND (A68_TRUE, ERROR_ASSERTION, __func__)\
+    ABEND (A68G_TRUE, ERROR_ASSERTION, __func__)\
   }}
 #else
 #define ASSERT(f) {\
@@ -191,24 +191,24 @@
 
 // Macro's for fat A68 pointers
 
-#define ADDRESS(z) (&(((IS_IN_HEAP (z) || IS_IN_COMMON (z)) ? REF_POINTER (z) : A68_STACK)[REF_OFFSET (z)]))
+#define ADDRESS(z) (&(((IS_IN_HEAP (z) || IS_IN_COMMON (z)) ? REF_POINTER (z) : A68G_STACK)[REF_OFFSET (z)]))
 #define ARRAY_ADDRESS(z) (&(REF_POINTER (z)[REF_OFFSET (z)]))
 #define DEREF(mode, expr) ((mode *) ADDRESS (expr))
-#define FILE_DEREF(p) DEREF (A68_FILE, (p))
-#define HEAP_ADDRESS(n) ((BYTE_T *) & (A68_HEAP[n]))
+#define FILE_DEREF(p) DEREF (A68G_FILE, (p))
+#define HEAP_ADDRESS(n) ((BYTE_T *) & (A68G_HEAP[n]))
 #define IS_IN_FRAME(z) (STATUS (z) & IN_FRAME_MASK)
 #define IS_IN_HEAP(z) (STATUS (z) & IN_HEAP_MASK)
 #define IS_IN_COMMON(z) (STATUS (z) & IN_COMMON_MASK)
 #define IS_IN_STACK(z) (STATUS (z) & IN_STACK_MASK)
 #define IS_NIL(p) ((BOOL_T) ((STATUS (&(p)) & NIL_MASK) != 0))
-#define LOCAL_ADDRESS(z) (& A68_STACK[REF_OFFSET (z)])
+#define LOCAL_ADDRESS(z) (& A68G_STACK[REF_OFFSET (z)])
 #define REF_HANDLE(z) (HANDLE (z))
 #define REF_OFFSET(z) (OFFSET (z))
 #define REF_POINTER(z) (POINTER (REF_HANDLE (z)))
 #define REF_SCOPE(z) (SCOPE (z))
-#define STACK_ADDRESS(n) ((BYTE_T *) &(A68_STACK[(n)]))
-#define STACK_OFFSET(n) (STACK_ADDRESS (A68_SP + (int) (n)))
-#define STACK_TOP (STACK_ADDRESS (A68_SP))
+#define STACK_ADDRESS(n) ((BYTE_T *) &(A68G_STACK[(n)]))
+#define STACK_OFFSET(n) (STACK_ADDRESS (A68G_SP + (int) (n)))
+#define STACK_TOP (STACK_ADDRESS (A68G_SP))
 
 // Miscellaneous macros
 
@@ -220,14 +220,14 @@
 #define FORWARD(p) ((p) = NEXT (p))
 #define PM(m) (moid_to_string (m, 132, NO_NODE))
 #define SIGN(n) ((n) == 0 ? 0 : ((n) > 0 ? 1 : -1))
-#define WIS(p) where_in_source (A68_STDOUT, (p))
+#define WIS(p) where_in_source (A68G_STDOUT, (p))
 #define WRITE(f, s) io_write_string ((f), (s));
 #define WRITELN(f, s) {WRITE ((f), "\n"); WRITE ((f), (s));}
 
 // Access macros
 
 #define A(p) ((p)->a)
-#define A68_STANDENV_PROC(p) ((p)->a68g_standenv_proc)
+#define A68G_STANDENV_PROC(p) ((p)->a68g_standenv_proc)
 #define ACTION(p) ((p)->action)
 #define ACTIVE(p) ((p)->active)
 #define ADDR(p) ((p)->addr)
@@ -448,6 +448,7 @@
 #define OPTION_CLOCK(p) (OPTIONS (p).clock)
 #define OPTION_COMPILE(p) (OPTIONS (p).compile)
 #define OPTION_COMPILE_CHECK(p) (OPTIONS (p).compile_check)
+#define OPTION_CONSERVATIVE_GC(p) (OPTIONS (p).conservative_gc)
 #define OPTION_CROSS_REFERENCE(p) (OPTIONS (p).cross_reference)
 #define OPTION_DEBUG(p) (OPTIONS (p).debug)
 #define OPTION_FOLD(p) (OPTIONS (p).fold)
@@ -458,6 +459,7 @@
 #define OPTION_LOCAL(p) (OPTIONS (p).local)
 #define OPTION_MOID_LISTING(p) (OPTIONS (p).moid_listing)
 #define OPTION_NODEMASK(p) (OPTIONS (p).nodemask)
+#define OPTION_NO_NOTICES(p) (OPTIONS (p).no_notices)
 #define OPTION_NO_WARNINGS(p) (OPTIONS (p).no_warnings)
 #define OPTION_OBJECT_LISTING(p) (OPTIONS (p).object_listing)
 #define OPTION_OPT_LEVEL(p) (OPTIONS (p).opt_level)
@@ -486,7 +488,7 @@
 #define P(q) ((q)->p)
 #define PACK(p) ((p)->pack)
 #define PAGE_END_MENDED(p) ((p)->page_end_mended)
-#define A68_PAGE_SIZE(p) ((p)->page_size)
+#define A68G_PAGE_SIZE(p) ((p)->page_size)
 #define PARAMETERS(p) ((p)->parameters)
 #define PARAMETER_LEVEL(p) ((p)->parameter_level)
 #define GSL_PARAMS(p) ((p)->params)
@@ -596,6 +598,7 @@
 #define TAG_LEX_LEVEL(p) (LEVEL (TAG_TABLE (p)))
 #define TAG_TABLE(p) ((p)->symbol_table)
 #define TAX(p) ((p)->tag)
+#define TAX_GC(p) ((p)->tag_gc)
 #define TERM(p) ((p)->term)
 #define TERMINATOR(p) ((p)->terminator)
 #define TEXT(p) ((p)->text)
@@ -627,7 +630,7 @@
 #define TV_USEC(p) ((p)->tv_usec)
 #define UNDO(p) ((p)->undo)
 #define UNDO_LINE(p) ((p)->undo_line)
-#define UNION_OFFSET (SIZE_ALIGNED (A68_UNION))
+#define UNION_OFFSET (SIZE_ALIGNED (A68G_UNION))
 #define UNIT(p) ((p)->unit)
 #define UPB(p) ((p)->upper_bound)
 #define UPPER_BOUND(p) ((p)->upper_bound)
@@ -643,7 +646,8 @@
 #define IS_LITERALLY(p, s) (strcmp (NSYMBOL (p), s) == 0)
 #define IS_NEW_LEXICAL_LEVEL(p) ((p)->is_new_lexical_level)
 #define ISNT(p, s) (! IS (p, s))
-#define IS(p, s) ((void *) (p) == NO_REF ? A68_FALSE : ATTRIBUTE (p) == (s))
+#define IS(p, s) ((void *) (p) == NO_REF ? A68G_FALSE : ATTRIBUTE (p) == (s))
+#define IS_PROC(m) IS ((m), PROC_SYMBOL)
 #define IS_REF_FLEX(m) (IS (m, REF_SYMBOL) && IS (SUB (m), FLEX_SYMBOL))
 #define IS_REF(m) IS ((m), REF_SYMBOL)
 #define IS_ROW(m) IS ((m), ROW_SYMBOL)
