@@ -31,31 +31,31 @@
 #define COMPLEX_T double complex
 
 typedef unt char BYTE_T;
-typedef BYTE_T *A68_STRUCT;
+typedef BYTE_T *A68G_STRUCT;
 
 typedef char BUFFER[BUFFER_SIZE + 1];
 typedef int CHAR_T;
 typedef int LEAP_T;
-typedef MP_T A68_LONG[DEFAULT_DOUBLE_DIGITS + 2];
-typedef struct A68_ARRAY A68_ARRAY;
-typedef struct A68_BITS A68_BITS;
-typedef struct A68_BOOL A68_BOOL;
-typedef struct A68_BYTES A68_BYTES;
-typedef struct A68_CHANNEL A68_CHANNEL;
-typedef struct A68_CHAR A68_CHAR;
-typedef struct A68_COLLITEM A68_COLLITEM;
-typedef struct A68_FILE A68_FILE;
-typedef struct A68_FORMAT A68_FORMAT;
-typedef struct A68_HANDLE A68_HANDLE;
-typedef struct A68_INT A68_INT;
-typedef struct A68_LONG_BYTES A68_LONG_BYTES;
-typedef struct A68_PROCEDURE A68_PROCEDURE;
-typedef struct A68_REAL A68_REAL;
-typedef struct A68_REF A68_REF, A68_ROW;
-typedef struct A68_SOUND A68_SOUND;
-typedef struct A68_STREAM A68_STREAM;
-typedef struct A68_TUPLE A68_TUPLE;
-typedef struct A68_UNION A68_UNION;
+typedef MP_T A68G_LONG[DEFAULT_DOUBLE_DIGITS + 2];
+typedef struct A68G_ARRAY A68G_ARRAY;
+typedef struct A68G_BITS A68G_BITS;
+typedef struct A68G_BOOL A68G_BOOL;
+typedef struct A68G_BYTES A68G_BYTES;
+typedef struct A68G_CHANNEL A68G_CHANNEL;
+typedef struct A68G_CHAR A68G_CHAR;
+typedef struct A68G_COLLITEM A68G_COLLITEM;
+typedef struct A68G_FILE A68G_FILE;
+typedef struct A68G_FORMAT A68G_FORMAT;
+typedef struct A68G_HANDLE A68G_HANDLE;
+typedef struct A68G_INT A68G_INT;
+typedef struct A68G_LONG_BYTES A68G_LONG_BYTES;
+typedef struct A68G_PROCEDURE A68G_PROCEDURE;
+typedef struct A68G_REAL A68G_REAL;
+typedef struct A68G_REF A68G_REF, A68G_ROW;
+typedef struct A68G_SOUND A68G_SOUND;
+typedef struct A68G_STREAM A68G_STREAM;
+typedef struct A68G_TUPLE A68G_TUPLE;
+typedef struct A68G_UNION A68G_UNION;
 typedef struct ACTIVATION_RECORD ACTIVATION_RECORD;
 typedef struct DEC_T DEC_T;
 typedef struct DIAGNOSTIC_T DIAGNOSTIC_T;
@@ -81,7 +81,7 @@ typedef void GPROC (NODE_T *);
 
 typedef PROP_T PROP_PROC (NODE_T *);
 
-struct A68_REAL
+struct A68G_REAL
 {
   STATUS_MASK_T status;
   REAL_T value;
@@ -112,7 +112,7 @@ struct PROP_T
   NODE_T *source;
 };
 
-struct A68_STREAM
+struct A68G_STREAM
 {
   char *name;
   FILE_T fd;
@@ -131,7 +131,7 @@ struct DIAGNOSTIC_T
 struct FILES_T
 {
   char *path, *initial_name, *generic_name;
-  struct A68_STREAM binary, diags, plugin, script, object, source, listing, pretty;
+  struct A68G_STREAM binary, diags, plugin, script, object, source, listing, pretty;
 };
 
 struct KEYWORD_T
@@ -164,7 +164,11 @@ struct MODES_T
 struct OPTIONS_T
 {
   OPTION_LIST_T *list;
-  BOOL_T backtrace, brackets, check_only, clock, cross_reference, debug, compile, compile_check, keep, fold, license, moid_listing, object_listing, portcheck, pragmat_sema, pretty, reductions, regression_test, run, rerun, run_script, source_listing, standard_prelude_listing, statistics_listing, strict, stropping, trace, tree_listing, unused, verbose, version, no_warnings, quiet;
+  BOOL_T backtrace, brackets, check_only, clock, compile, compile_check, conservative_gc, 
+    cross_reference, debug, fold, keep, license, moid_listing, no_notices, no_warnings, object_listing, 
+    portcheck, pragmat_sema, pretty, quiet, reductions, regression_test, rerun, run, run_script, 
+    source_listing, standard_prelude_listing, statistics_listing, strict, stropping, trace, 
+    tree_listing, unused, verbose, version; 
   int time_limit, opt_level, indent;
   STATUS_MASK_T nodemask;
 };
@@ -189,7 +193,7 @@ struct NODE_T
   PACK_T *pack;
   STATUS_MASK_T status, codex;
   TABLE_T *symbol_table, *non_local;
-  TAG_T *tag;
+  TAG_T *tag, *tag_gc;
 };
 #define NO_NODE ((NODE_T *) NULL)
 
@@ -296,45 +300,45 @@ struct TOKEN_T
   TOKEN_T *less, *more;
 };
 
-//! @struct A68_HANDLE
+//! @struct A68G_HANDLE
 //! @brief Handle for REF into the HEAP.
 //! @details
 //! A REF into the HEAP points at a HANDLE.
 //! The HANDLE points at the actual object in the HEAP.
 //! Garbage collection modifies HANDLEs, but not REFs.
 
-struct A68_HANDLE
+struct A68G_HANDLE
 {
   STATUS_MASK_T status;
   BYTE_T *pointer;
   int size;
   MOID_T *type;
-  A68_HANDLE *next, *previous;
+  A68G_HANDLE *next, *previous;
 } ALIGNED;
 
-//! @struct A68_REF
+//! @struct A68G_REF
 //! @brief Fat A68 pointer.
 
-struct A68_REF
+struct A68G_REF
 {
   STATUS_MASK_T status;
   ADDR_T offset;
   ADDR_T scope; // Dynamic scope.
-  A68_HANDLE *handle;
+  A68G_HANDLE *handle;
 } ALIGNED;
 
-//! @struct A68_ARRAY
+//! @struct A68G_ARRAY
 //! @brief A68 array descriptor. 
 //! @details
-//! A row is an A68_REF to an A68_ARRAY.
+//! A row is an A68G_REF to an A68G_ARRAY.
 //! 
-//! An A68_ARRAY is followed by one A68_TUPLE per dimension.
+//! An A68G_ARRAY is followed by one A68G_TUPLE per dimension.
 //! 
 //! @verbatim
-//! A68_REF row -> A68_ARRAY ----+   ARRAY: Description of row, ref to elements.
-//!                A68_TUPLE 1   |   TUPLE: Bounds, one for every dimension.
+//! A68G_REF row -> A68G_ARRAY ----+   ARRAY: Description of row, ref to elements.
+//!                A68G_TUPLE 1   |   TUPLE: Bounds, one for every dimension.
 //!                ...           |
-//!                A68_TUPLE dim |
+//!                A68G_TUPLE dim |
 //!                ...           |
 //!                ...           |
 //!                Element 1 <---+   Sequential row elements in the heap.
@@ -342,78 +346,78 @@ struct A68_REF
 //!                Element n
 //! @endverbatim
 
-struct A68_ARRAY
+struct A68G_ARRAY
 {
   MOID_T *type;
   int dim, elem_size;
   ADDR_T slice_offset, field_offset;
-  A68_REF array;
+  A68G_REF array;
 } ALIGNED;
 
-struct A68_BITS
+struct A68G_BITS
 {
   STATUS_MASK_T status;
   UNSIGNED_T value;
 } ALIGNED;
 
-struct A68_BYTES
+struct A68G_BYTES
 {
   STATUS_MASK_T status;
-  char value[A68_BYTES_WIDTH + 1];
+  char value[A68G_BYTES_WIDTH + 1];
 } ALIGNED;
 
-struct A68_CHANNEL
+struct A68G_CHANNEL
 {
   STATUS_MASK_T status;
   BOOL_T reset, set, get, put, bin, draw, compress;
 } ALIGNED;
 
-struct A68_BOOL
+struct A68G_BOOL
 {
   STATUS_MASK_T status;
   BOOL_T value;
 } ALIGNED;
 
-struct A68_CHAR
+struct A68G_CHAR
 {
   STATUS_MASK_T status;
   CHAR_T value;
 } ALIGNED;
 
-struct A68_COLLITEM
+struct A68G_COLLITEM
 {
   STATUS_MASK_T status;
   int count;
 };
 
-struct A68_INT
+struct A68G_INT
 {
   STATUS_MASK_T status;
   INT_T value;
 } ALIGNED;
 
-//! @struct A68_FORMAT
+//! @struct A68G_FORMAT
 //! @brief A68 format descriptor.
 //! @details
 //! A format behaves very much like a procedure.
 
-struct A68_FORMAT
+struct A68G_FORMAT
 {
   STATUS_MASK_T status;
   NODE_T *body;      // Entry point in syntax tree.
   ADDR_T fp_environ; // Frame pointer to environ.
 } ALIGNED;
 
-struct A68_LONG_BYTES
+struct A68G_LONG_BYTES
 {
   STATUS_MASK_T status;
-  char value[A68_LONG_BYTES_WIDTH + 1];
+  char value[A68G_LONG_BYTES_WIDTH + 1];
 } ALIGNED;
 
-//! @struct A68_PROCEDURE
+//! @struct A68G_PROCEDURE
 //! @brief A68 procedure descriptor.
 
-struct A68_PROCEDURE
+struct A68G_PROCEDURE
 {
   STATUS_MASK_T status;
   union
@@ -421,41 +425,41 @@ struct A68_PROCEDURE
     NODE_T *node;
     GPROC *procedure;
   } body;             // Entry point in syntax tree or precompiled C procedure.
-  A68_HANDLE *locale; // Locale for partial parametrisation.
+  A68G_HANDLE *locale; // Locale for partial parametrisation.
   MOID_T *type;
   ADDR_T fp_environ;  // Frame pointer to environ.
 } ALIGNED;
 
-typedef A68_REAL A68_COMPLEX[2];
+typedef A68G_REAL A68G_COMPLEX[2];
 
-//! @struct A68_TUPLE
+//! @struct A68G_TUPLE
 //! @brief A tuple containing bounds etcetera for one dimension.
 
-struct A68_TUPLE
+struct A68G_TUPLE
 {
   INT_T upper_bound, lower_bound, shift, span, k;
 } ALIGNED;
 
-struct A68_UNION
+struct A68G_UNION
 {
   STATUS_MASK_T status;
   void *value;
 } ALIGNED;
 
-struct A68_SOUND
+struct A68G_SOUND
 {
   STATUS_MASK_T status;
   unt num_channels, sample_rate, bits_per_sample, num_samples, data_size;
-  A68_REF data;
+  A68G_REF data;
 };
 
-struct A68_FILE
+struct A68G_FILE
 {
   STATUS_MASK_T status;
-  A68_CHANNEL channel;
-  A68_FORMAT format;
-  A68_PROCEDURE file_end_mended, page_end_mended, line_end_mended, value_error_mended, open_error_mended, transput_error_mended, format_end_mended, format_error_mended;
-  A68_REF identification, terminator, string;
+  A68G_CHANNEL channel;
+  A68G_FORMAT format;
+  A68G_PROCEDURE file_end_mended, page_end_mended, line_end_mended, value_error_mended, open_error_mended, transput_error_mended, format_end_mended, format_error_mended;
+  A68G_REF identification, terminator, string;
   ADDR_T frame_pointer, stack_pointer;  // Since formats open frames
   BOOL_T read_mood, write_mood, char_mood, draw_mood, opened, open_exclusive, end_of_file, tmp_file;
   FILE_T fd;
@@ -468,13 +472,13 @@ struct A68_FILE
     plPlotterParams *plotter_params;
 #endif
     BOOL_T device_made, device_opened;
-    A68_REF device, page_size;
+    A68G_REF device, page_size;
     int device_handle /* deprecated */ , window_x_size, window_y_size;
     REAL_T x_coord, y_coord, red, green, blue;
   }
   device;
 #if defined (HAVE_POSTGRESQL)
-# if ! defined (A68_OPTIMISE)
+# if ! defined (A68G_OPTIMISE)
   PGconn *connection;
   PGresult *result;
 # endif
